@@ -716,6 +716,16 @@ namespace Boo.Lang.Compiler
 			return new CompilerError("BCE0134", node.LexicalInfo, node);
 		}
 		
+		public static CompilerError InvalidName(Node node, string name)
+		{
+			return new CompilerError("BCE0135", node.LexicalInfo, name);
+		}
+		
+		public static CompilerError ColonInsteadOfEquals(Node node)
+		{
+			return new CompilerError("BCE0136", node.LexicalInfo);
+		}
+		
 		public static string ToStringList(System.Collections.IEnumerable names)
 		{
 			StringBuilder builder = new StringBuilder();
