@@ -27,7 +27,7 @@
 #endregion
 
 
-// $ANTLR 2.7.5 (20050517): "booel.g" -> "BooExpressionLexer.cs"$
+// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/booel.g" -> "BooExpressionLexer.cs"$
 
 namespace Boo.Lang.Parser
 {
@@ -68,133 +68,135 @@ namespace Boo.Lang.Parser
 		public const int ELIST = 6;
 		public const int DLIST = 7;
 		public const int ESEPARATOR = 8;
-		public const int ABSTRACT = 9;
-		public const int AND = 10;
-		public const int AS = 11;
-		public const int AST = 12;
-		public const int BREAK = 13;
-		public const int CONTINUE = 14;
-		public const int CALLABLE = 15;
-		public const int CAST = 16;
-		public const int CHAR = 17;
-		public const int CLASS = 18;
-		public const int CONSTRUCTOR = 19;
-		public const int DEF = 20;
-		public const int DESTRUCTOR = 21;
-		public const int DO = 22;
-		public const int ELIF = 23;
-		public const int ELSE = 24;
-		public const int ENSURE = 25;
-		public const int ENUM = 26;
-		public const int EVENT = 27;
-		public const int EXCEPT = 28;
-		public const int FAILURE = 29;
-		public const int FINAL = 30;
-		public const int FROM = 31;
-		public const int FOR = 32;
-		public const int FALSE = 33;
-		public const int GET = 34;
-		public const int GIVEN = 35;
-		public const int GOTO = 36;
-		public const int IMPORT = 37;
-		public const int INTERFACE = 38;
-		public const int INTERNAL = 39;
-		public const int IS = 40;
-		public const int ISA = 41;
-		public const int IF = 42;
-		public const int IN = 43;
-		public const int NOT = 44;
-		public const int NULL = 45;
-		public const int OF = 46;
-		public const int OR = 47;
-		public const int OTHERWISE = 48;
-		public const int OVERRIDE = 49;
-		public const int PASS = 50;
-		public const int NAMESPACE = 51;
-		public const int PARTIAL = 52;
-		public const int PUBLIC = 53;
-		public const int PROTECTED = 54;
-		public const int PRIVATE = 55;
-		public const int RAISE = 56;
-		public const int REF = 57;
-		public const int RETURN = 58;
-		public const int RETRY = 59;
-		public const int SET = 60;
-		public const int SELF = 61;
-		public const int SUPER = 62;
-		public const int STATIC = 63;
-		public const int SUCCESS = 64;
-		public const int STRUCT = 65;
-		public const int TRY = 66;
-		public const int TRANSIENT = 67;
-		public const int TRUE = 68;
-		public const int TYPEOF = 69;
-		public const int UNLESS = 70;
-		public const int VIRTUAL = 71;
-		public const int WHEN = 72;
-		public const int WHILE = 73;
-		public const int YIELD = 74;
-		public const int EOS = 75;
+		public const int EOL = 9;
+		public const int ABSTRACT = 10;
+		public const int AND = 11;
+		public const int AS = 12;
+		public const int AST = 13;
+		public const int BREAK = 14;
+		public const int CONTINUE = 15;
+		public const int CALLABLE = 16;
+		public const int CAST = 17;
+		public const int CHAR = 18;
+		public const int CLASS = 19;
+		public const int CONSTRUCTOR = 20;
+		public const int DEF = 21;
+		public const int DESTRUCTOR = 22;
+		public const int DO = 23;
+		public const int ELIF = 24;
+		public const int ELSE = 25;
+		public const int ENSURE = 26;
+		public const int ENUM = 27;
+		public const int EVENT = 28;
+		public const int EXCEPT = 29;
+		public const int FAILURE = 30;
+		public const int FINAL = 31;
+		public const int FROM = 32;
+		public const int FOR = 33;
+		public const int FALSE = 34;
+		public const int GET = 35;
+		public const int GIVEN = 36;
+		public const int GOTO = 37;
+		public const int IMPORT = 38;
+		public const int INTERFACE = 39;
+		public const int INTERNAL = 40;
+		public const int IS = 41;
+		public const int ISA = 42;
+		public const int IF = 43;
+		public const int IN = 44;
+		public const int NOT = 45;
+		public const int NULL = 46;
+		public const int OF = 47;
+		public const int OR = 48;
+		public const int OTHERWISE = 49;
+		public const int OVERRIDE = 50;
+		public const int PASS = 51;
+		public const int NAMESPACE = 52;
+		public const int PARTIAL = 53;
+		public const int PUBLIC = 54;
+		public const int PROTECTED = 55;
+		public const int PRIVATE = 56;
+		public const int RAISE = 57;
+		public const int REF = 58;
+		public const int RETURN = 59;
+		public const int RETRY = 60;
+		public const int SET = 61;
+		public const int SELF = 62;
+		public const int SUPER = 63;
+		public const int STATIC = 64;
+		public const int SUCCESS = 65;
+		public const int STRUCT = 66;
+		public const int TRY = 67;
+		public const int TRANSIENT = 68;
+		public const int TRUE = 69;
+		public const int TYPEOF = 70;
+		public const int UNLESS = 71;
+		public const int VIRTUAL = 72;
+		public const int WHEN = 73;
+		public const int WHILE = 74;
+		public const int YIELD = 75;
 		public const int TRIPLE_QUOTED_STRING = 76;
-		public const int DOUBLE_QUOTED_STRING = 77;
-		public const int SINGLE_QUOTED_STRING = 78;
-		public const int ID = 79;
-		public const int LPAREN = 80;
-		public const int RPAREN = 81;
-		public const int ASSIGN = 82;
-		public const int SUBTRACT = 83;
-		public const int LBRACK = 84;
-		public const int COMMA = 85;
-		public const int RBRACK = 86;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 87;
-		public const int DOT = 88;
-		public const int COLON = 89;
-		public const int MULTIPLY = 90;
-		public const int BITWISE_OR = 91;
-		public const int LBRACE = 92;
-		public const int RBRACE = 93;
-		public const int INPLACE_BITWISE_OR = 94;
-		public const int INPLACE_BITWISE_AND = 95;
-		public const int INPLACE_SHIFT_LEFT = 96;
-		public const int INPLACE_SHIFT_RIGHT = 97;
-		public const int CMP_OPERATOR = 98;
-		public const int GREATER_THAN = 99;
-		public const int LESS_THAN = 100;
-		public const int ADD = 101;
-		public const int EXCLUSIVE_OR = 102;
-		public const int DIVISION = 103;
-		public const int MODULUS = 104;
-		public const int BITWISE_AND = 105;
-		public const int SHIFT_LEFT = 106;
-		public const int SHIFT_RIGHT = 107;
-		public const int EXPONENTIATION = 108;
-		public const int INCREMENT = 109;
-		public const int DECREMENT = 110;
-		public const int ONES_COMPLEMENT = 111;
-		public const int INT = 112;
-		public const int LONG = 113;
-		public const int RE_LITERAL = 114;
-		public const int DOUBLE = 115;
-		public const int FLOAT = 116;
-		public const int TIMESPAN = 117;
-		public const int LINE_CONTINUATION = 118;
-		public const int SL_COMMENT = 119;
-		public const int ML_COMMENT = 120;
-		public const int WS = 121;
-		public const int X_RE_LITERAL = 122;
-		public const int NEWLINE = 123;
-		public const int ESCAPED_EXPRESSION = 124;
-		public const int DQS_ESC = 125;
-		public const int SQS_ESC = 126;
-		public const int SESC = 127;
-		public const int RE_CHAR = 128;
-		public const int X_RE_CHAR = 129;
-		public const int RE_ESC = 130;
-		public const int DIGIT_GROUP = 131;
-		public const int REVERSE_DIGIT_GROUP = 132;
-		public const int ID_LETTER = 133;
-		public const int DIGIT = 134;
-		public const int HEXDIGIT = 135;
+		public const int EOS = 77;
+		public const int DOUBLE_QUOTED_STRING = 78;
+		public const int SINGLE_QUOTED_STRING = 79;
+		public const int ID = 80;
+		public const int LPAREN = 81;
+		public const int RPAREN = 82;
+		public const int ASSIGN = 83;
+		public const int SUBTRACT = 84;
+		public const int LBRACK = 85;
+		public const int COMMA = 86;
+		public const int RBRACK = 87;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 88;
+		public const int DOT = 89;
+		public const int COLON = 90;
+		public const int MULTIPLY = 91;
+		public const int BITWISE_OR = 92;
+		public const int LBRACE = 93;
+		public const int RBRACE = 94;
+		public const int INPLACE_BITWISE_OR = 95;
+		public const int INPLACE_BITWISE_AND = 96;
+		public const int INPLACE_SHIFT_LEFT = 97;
+		public const int INPLACE_SHIFT_RIGHT = 98;
+		public const int CMP_OPERATOR = 99;
+		public const int GREATER_THAN = 100;
+		public const int LESS_THAN = 101;
+		public const int ADD = 102;
+		public const int EXCLUSIVE_OR = 103;
+		public const int DIVISION = 104;
+		public const int MODULUS = 105;
+		public const int BITWISE_AND = 106;
+		public const int SHIFT_LEFT = 107;
+		public const int SHIFT_RIGHT = 108;
+		public const int EXPONENTIATION = 109;
+		public const int INCREMENT = 110;
+		public const int DECREMENT = 111;
+		public const int ONES_COMPLEMENT = 112;
+		public const int INT = 113;
+		public const int LONG = 114;
+		public const int RE_LITERAL = 115;
+		public const int DOUBLE = 116;
+		public const int FLOAT = 117;
+		public const int TIMESPAN = 118;
+		public const int LINE_CONTINUATION = 119;
+		public const int SL_COMMENT = 120;
+		public const int ML_COMMENT = 121;
+		public const int WS = 122;
+		public const int X_RE_LITERAL = 123;
+		public const int NEWLINE = 124;
+		public const int ESCAPED_EXPRESSION = 125;
+		public const int DQS_ESC = 126;
+		public const int SQS_ESC = 127;
+		public const int SESC = 128;
+		public const int RE_CHAR = 129;
+		public const int X_RE_CHAR = 130;
+		public const int RE_ESC = 131;
+		public const int DIGIT_GROUP = 132;
+		public const int REVERSE_DIGIT_GROUP = 133;
+		public const int ID_PREFIX = 134;
+		public const int ID_LETTER = 135;
+		public const int DIGIT = 136;
+		public const int HEXDIGIT = 137;
 		
 		
 	
@@ -228,72 +230,72 @@ namespace Boo.Lang.Parser
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 53);
-			literals.Add("namespace", 51);
-			literals.Add("break", 13);
-			literals.Add("while", 73);
-			literals.Add("otherwise", 48);
-			literals.Add("raise", 56);
-			literals.Add("typeof", 69);
-			literals.Add("and", 10);
-			literals.Add("failure", 29);
-			literals.Add("not", 44);
-			literals.Add("return", 58);
-			literals.Add("pass", 50);
-			literals.Add("from", 31);
-			literals.Add("null", 45);
-			literals.Add("def", 20);
-			literals.Add("given", 35);
-			literals.Add("protected", 54);
-			literals.Add("ref", 57);
-			literals.Add("retry", 59);
-			literals.Add("when", 72);
-			literals.Add("class", 18);
-			literals.Add("do", 22);
-			literals.Add("except", 28);
-			literals.Add("event", 27);
-			literals.Add("ast", 12);
-			literals.Add("unless", 70);
-			literals.Add("super", 62);
-			literals.Add("set", 60);
-			literals.Add("transient", 67);
-			literals.Add("constructor", 19);
-			literals.Add("interface", 38);
-			literals.Add("of", 46);
-			literals.Add("is", 40);
-			literals.Add("internal", 39);
-			literals.Add("final", 30);
-			literals.Add("yield", 74);
-			literals.Add("or", 47);
-			literals.Add("destructor", 21);
-			literals.Add("if", 42);
-			literals.Add("success", 64);
-			literals.Add("override", 49);
-			literals.Add("as", 11);
-			literals.Add("try", 66);
-			literals.Add("goto", 36);
-			literals.Add("enum", 26);
-			literals.Add("isa", 41);
-			literals.Add("for", 32);
-			literals.Add("char", 17);
-			literals.Add("private", 55);
-			literals.Add("false", 33);
-			literals.Add("static", 63);
-			literals.Add("abstract", 9);
-			literals.Add("partial", 52);
-			literals.Add("callable", 15);
-			literals.Add("get", 34);
-			literals.Add("continue", 14);
-			literals.Add("cast", 16);
-			literals.Add("struct", 65);
-			literals.Add("else", 24);
-			literals.Add("import", 37);
-			literals.Add("elif", 23);
-			literals.Add("in", 43);
-			literals.Add("self", 61);
-			literals.Add("ensure", 25);
-			literals.Add("true", 68);
-			literals.Add("virtual", 71);
+			literals.Add("public", 54);
+			literals.Add("namespace", 52);
+			literals.Add("break", 14);
+			literals.Add("while", 74);
+			literals.Add("otherwise", 49);
+			literals.Add("raise", 57);
+			literals.Add("typeof", 70);
+			literals.Add("and", 11);
+			literals.Add("failure", 30);
+			literals.Add("not", 45);
+			literals.Add("return", 59);
+			literals.Add("pass", 51);
+			literals.Add("from", 32);
+			literals.Add("null", 46);
+			literals.Add("def", 21);
+			literals.Add("given", 36);
+			literals.Add("protected", 55);
+			literals.Add("ref", 58);
+			literals.Add("retry", 60);
+			literals.Add("when", 73);
+			literals.Add("class", 19);
+			literals.Add("do", 23);
+			literals.Add("except", 29);
+			literals.Add("event", 28);
+			literals.Add("ast", 13);
+			literals.Add("unless", 71);
+			literals.Add("super", 63);
+			literals.Add("set", 61);
+			literals.Add("transient", 68);
+			literals.Add("constructor", 20);
+			literals.Add("interface", 39);
+			literals.Add("of", 47);
+			literals.Add("is", 41);
+			literals.Add("internal", 40);
+			literals.Add("final", 31);
+			literals.Add("yield", 75);
+			literals.Add("or", 48);
+			literals.Add("destructor", 22);
+			literals.Add("if", 43);
+			literals.Add("success", 65);
+			literals.Add("override", 50);
+			literals.Add("as", 12);
+			literals.Add("try", 67);
+			literals.Add("goto", 37);
+			literals.Add("enum", 27);
+			literals.Add("isa", 42);
+			literals.Add("for", 33);
+			literals.Add("char", 18);
+			literals.Add("private", 56);
+			literals.Add("false", 34);
+			literals.Add("static", 64);
+			literals.Add("abstract", 10);
+			literals.Add("partial", 53);
+			literals.Add("callable", 16);
+			literals.Add("get", 35);
+			literals.Add("continue", 15);
+			literals.Add("cast", 17);
+			literals.Add("struct", 66);
+			literals.Add("else", 25);
+			literals.Add("import", 38);
+			literals.Add("elif", 24);
+			literals.Add("in", 44);
+			literals.Add("self", 62);
+			literals.Add("ensure", 26);
+			literals.Add("true", 69);
+			literals.Add("virtual", 72);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
@@ -311,25 +313,6 @@ tryAgain:
 					{
 						switch ( cached_LA1 )
 						{
-						case 'A':  case 'B':  case 'C':  case 'D':
-						case 'E':  case 'F':  case 'G':  case 'H':
-						case 'I':  case 'J':  case 'K':  case 'L':
-						case 'M':  case 'N':  case 'O':  case 'P':
-						case 'Q':  case 'R':  case 'S':  case 'T':
-						case 'U':  case 'V':  case 'W':  case 'X':
-						case 'Y':  case 'Z':  case '_':  case 'a':
-						case 'b':  case 'c':  case 'd':  case 'e':
-						case 'f':  case 'g':  case 'h':  case 'i':
-						case 'j':  case 'k':  case 'l':  case 'm':
-						case 'n':  case 'o':  case 'p':  case 'q':
-						case 'r':  case 's':  case 't':  case 'u':
-						case 'v':  case 'w':  case 'x':  case 'y':
-						case 'z':
-						{
-							mID(true);
-							theRetToken = returnToken_;
-							break;
-						}
 						case '0':  case '1':  case '2':  case '3':
 						case '4':  case '5':  case '6':  case '7':
 						case '8':  case '9':
@@ -482,6 +465,10 @@ tryAgain:
 								mCMP_OPERATOR(true);
 								theRetToken = returnToken_;
 							}
+							else if ((tokenSet_0_.member(cached_LA1))) {
+								mID(true);
+								theRetToken = returnToken_;
+							}
 							else if ((cached_LA1=='+') && (true)) {
 								mADD(true);
 								theRetToken = returnToken_;
@@ -529,44 +516,37 @@ tryAgain:
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = ID;
 		
+		{
+			if ((cached_LA1=='$'||cached_LA1=='?'||cached_LA1=='@'))
+			{
+				mID_PREFIX(false);
+			}
+			else if ((tokenSet_1_.member(cached_LA1))) {
+			}
+			else
+			{
+				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+			}
+			
+		}
 		mID_LETTER(false);
 		{    // ( ... )*
 			for (;;)
 			{
-				switch ( cached_LA1 )
-				{
-				case 'A':  case 'B':  case 'C':  case 'D':
-				case 'E':  case 'F':  case 'G':  case 'H':
-				case 'I':  case 'J':  case 'K':  case 'L':
-				case 'M':  case 'N':  case 'O':  case 'P':
-				case 'Q':  case 'R':  case 'S':  case 'T':
-				case 'U':  case 'V':  case 'W':  case 'X':
-				case 'Y':  case 'Z':  case '_':  case 'a':
-				case 'b':  case 'c':  case 'd':  case 'e':
-				case 'f':  case 'g':  case 'h':  case 'i':
-				case 'j':  case 'k':  case 'l':  case 'm':
-				case 'n':  case 'o':  case 'p':  case 'q':
-				case 'r':  case 's':  case 't':  case 'u':
-				case 'v':  case 'w':  case 'x':  case 'y':
-				case 'z':
+				if ((tokenSet_1_.member(cached_LA1)))
 				{
 					mID_LETTER(false);
-					break;
 				}
-				case '0':  case '1':  case '2':  case '3':
-				case '4':  case '5':  case '6':  case '7':
-				case '8':  case '9':
-				{
+				else if (((cached_LA1 >= '0' && cached_LA1 <= '9'))) {
 					mDIGIT(false);
-					break;
 				}
-				default:
+				else
 				{
-					goto _loop3_breakloop;
+					goto _loop4_breakloop;
 				}
-				 }
+				
 			}
-_loop3_breakloop:			;
+_loop4_breakloop:			;
 		}    // ( ... )*
 		_ttype = testLiteralsTable(_ttype);
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -577,6 +557,41 @@ _loop3_breakloop:			;
 		returnToken_ = _token;
 	}
 	
+	protected void mID_PREFIX(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = ID_PREFIX;
+		
+		switch ( cached_LA1 )
+		{
+		case '$':
+		{
+			match('$');
+			break;
+		}
+		case '@':
+		{
+			match('@');
+			break;
+		}
+		case '?':
+		{
+			match('?');
+			break;
+		}
+		default:
+		{
+			throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+		}
+		 }
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
 	protected void mID_LETTER(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
 {
 		int _ttype; IToken _token=null; int _begin=text.Length;
@@ -613,10 +628,15 @@ _loop3_breakloop:			;
 				break;
 			}
 			default:
+				if ((((cached_LA1 >= '\u0080' && cached_LA1 <= '\ufffe')))&&(System.Char.IsLetter(LA(1))))
+				{
+					matchRange('\u0080','\uFFFE');
+				}
+			else
 			{
 				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
 			}
-			 }
+			break; }
 		}
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -650,21 +670,21 @@ _loop3_breakloop:			;
 			{
 				match("0x");
 				{ // ( ... )+
-					int _cnt7=0;
+					int _cnt8=0;
 					for (;;)
 					{
-						if ((tokenSet_0_.member(cached_LA1)))
+						if ((tokenSet_2_.member(cached_LA1)))
 						{
 							mHEXDIGIT(false);
 						}
 						else
 						{
-							if (_cnt7 >= 1) { goto _loop7_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt8 >= 1) { goto _loop8_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt7++;
+						_cnt8++;
 					}
-_loop7_breakloop:					;
+_loop8_breakloop:					;
 				}    // ( ... )+
 			}
 			{
@@ -1054,11 +1074,11 @@ _loop7_breakloop:					;
 				}
 				default:
 				{
-					goto _loop112_breakloop;
+					goto _loop113_breakloop;
 				}
 				 }
 			}
-_loop112_breakloop:			;
+_loop113_breakloop:			;
 		}    // ( ... )*
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1074,7 +1094,7 @@ _loop112_breakloop:			;
 		_ttype = REVERSE_DIGIT_GROUP;
 		
 		{ // ( ... )+
-			int _cnt116=0;
+			int _cnt117=0;
 			for (;;)
 			{
 				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
@@ -1100,12 +1120,12 @@ _loop112_breakloop:			;
 				}
 				else
 				{
-					if (_cnt116 >= 1) { goto _loop116_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt117 >= 1) { goto _loop117_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt116++;
+				_cnt117++;
 			}
-_loop116_breakloop:			;
+_loop117_breakloop:			;
 		}    // ( ... )+
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1586,11 +1606,11 @@ _loop116_breakloop:			;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched63 = false;
-		if (((cached_LA1=='/') && (tokenSet_1_.member(cached_LA2)) && (tokenSet_2_.member(LA(3)))))
+		bool synPredMatched64 = false;
+		if (((cached_LA1=='/') && (tokenSet_3_.member(cached_LA2)) && (tokenSet_4_.member(LA(3)))))
 		{
-			int _m63 = mark();
-			synPredMatched63 = true;
+			int _m64 = mark();
+			synPredMatched64 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1599,12 +1619,12 @@ _loop116_breakloop:			;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched63 = false;
+				synPredMatched64 = false;
 			}
-			rewind(_m63);
+			rewind(_m64);
 			inputState.guessing--;
 		}
-		if ( synPredMatched63 )
+		if ( synPredMatched64 )
 		{
 			mRE_LITERAL(false);
 			if (0==inputState.guessing)
@@ -1648,21 +1668,21 @@ _loop116_breakloop:			;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt99=0;
+			int _cnt100=0;
 			for (;;)
 			{
-				if ((tokenSet_1_.member(cached_LA1)))
+				if ((tokenSet_3_.member(cached_LA1)))
 				{
 					mRE_CHAR(false);
 				}
 				else
 				{
-					if (_cnt99 >= 1) { goto _loop99_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt100 >= 1) { goto _loop100_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt99++;
+				_cnt100++;
 			}
-_loop99_breakloop:			;
+_loop100_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -1860,7 +1880,7 @@ _loop99_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt78=0;
+			int _cnt79=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -1895,12 +1915,12 @@ _loop99_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt78 >= 1) { goto _loop78_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt79 >= 1) { goto _loop79_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt78++;
+				_cnt79++;
 			}
-_loop78_breakloop:			;
+_loop79_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -1930,18 +1950,18 @@ _loop78_breakloop:			;
 				{
 					mSQS_ESC(false);
 				}
-				else if ((tokenSet_3_.member(cached_LA1))) {
+				else if ((tokenSet_5_.member(cached_LA1))) {
 					{
-						match(tokenSet_3_);
+						match(tokenSet_5_);
 					}
 				}
 				else
 				{
-					goto _loop82_breakloop;
+					goto _loop83_breakloop;
 				}
 				
 			}
-_loop82_breakloop:			;
+_loop83_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2198,9 +2218,9 @@ _loop82_breakloop:			;
 		{
 			mRE_ESC(false);
 		}
-		else if ((tokenSet_4_.member(cached_LA1))) {
+		else if ((tokenSet_6_.member(cached_LA1))) {
 			{
-				match(tokenSet_4_);
+				match(tokenSet_6_);
 			}
 		}
 		else
@@ -2348,21 +2368,21 @@ _loop82_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt106=0;
+					int _cnt107=0;
 					for (;;)
 					{
-						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_2_.member(cached_LA2)) && (true))
+						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_4_.member(cached_LA2)) && (true))
 						{
 							mDIGIT(false);
 						}
 						else
 						{
-							if (_cnt106 >= 1) { goto _loop106_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt107 >= 1) { goto _loop107_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt106++;
+						_cnt107++;
 					}
-_loop106_breakloop:					;
+_loop107_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
@@ -2477,6 +2497,28 @@ _loop106_breakloop:					;
 	
 	
 	private static long[] mk_tokenSet_0_()
+	{
+		long[] data = new long[3072];
+		data[0]=-9223371968135299072L;
+		data[1]=576460745995190271L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
+	private static long[] mk_tokenSet_1_()
+	{
+		long[] data = new long[3072];
+		data[0]=0L;
+		data[1]=576460745995190270L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
+	private static long[] mk_tokenSet_2_()
 	{
 		long[] data = new long[1025];
 		data[0]=287948901175001088L;
@@ -2484,8 +2526,8 @@ _loop106_breakloop:					;
 		for (int i = 2; i<=1024; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
-	private static long[] mk_tokenSet_1_()
+	public static readonly BitSet tokenSet_2_ = new BitSet(mk_tokenSet_2_());
+	private static long[] mk_tokenSet_3_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140741783332360L;
@@ -2494,8 +2536,8 @@ _loop106_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
-	private static long[] mk_tokenSet_2_()
+	public static readonly BitSet tokenSet_3_ = new BitSet(mk_tokenSet_3_());
+	private static long[] mk_tokenSet_4_()
 	{
 		long[] data = new long[2048];
 		data[0]=-4294977032L;
@@ -2504,8 +2546,8 @@ _loop106_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_2_ = new BitSet(mk_tokenSet_2_());
-	private static long[] mk_tokenSet_3_()
+	public static readonly BitSet tokenSet_4_ = new BitSet(mk_tokenSet_4_());
+	private static long[] mk_tokenSet_5_()
 	{
 		long[] data = new long[2048];
 		data[0]=-549755823112L;
@@ -2515,8 +2557,8 @@ _loop106_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_3_ = new BitSet(mk_tokenSet_3_());
-	private static long[] mk_tokenSet_4_()
+	public static readonly BitSet tokenSet_5_ = new BitSet(mk_tokenSet_5_());
+	private static long[] mk_tokenSet_6_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140741783332360L;
@@ -2526,7 +2568,7 @@ _loop106_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_4_ = new BitSet(mk_tokenSet_4_());
+	public static readonly BitSet tokenSet_6_ = new BitSet(mk_tokenSet_6_());
 	
 }
 }
