@@ -27,7 +27,7 @@
 #endregion
 
 
-// $ANTLR 2.7.5 (20050517): "boo.g" -> "BooLexer.cs"$
+// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/boo.g" -> "BooLexer.cs"$
 
 namespace Boo.Lang.Parser
 {
@@ -70,133 +70,135 @@ using Boo.Lang.Parser.Util;
 		public const int ELIST = 6;
 		public const int DLIST = 7;
 		public const int ESEPARATOR = 8;
-		public const int ABSTRACT = 9;
-		public const int AND = 10;
-		public const int AS = 11;
-		public const int AST = 12;
-		public const int BREAK = 13;
-		public const int CONTINUE = 14;
-		public const int CALLABLE = 15;
-		public const int CAST = 16;
-		public const int CHAR = 17;
-		public const int CLASS = 18;
-		public const int CONSTRUCTOR = 19;
-		public const int DEF = 20;
-		public const int DESTRUCTOR = 21;
-		public const int DO = 22;
-		public const int ELIF = 23;
-		public const int ELSE = 24;
-		public const int ENSURE = 25;
-		public const int ENUM = 26;
-		public const int EVENT = 27;
-		public const int EXCEPT = 28;
-		public const int FAILURE = 29;
-		public const int FINAL = 30;
-		public const int FROM = 31;
-		public const int FOR = 32;
-		public const int FALSE = 33;
-		public const int GET = 34;
-		public const int GIVEN = 35;
-		public const int GOTO = 36;
-		public const int IMPORT = 37;
-		public const int INTERFACE = 38;
-		public const int INTERNAL = 39;
-		public const int IS = 40;
-		public const int ISA = 41;
-		public const int IF = 42;
-		public const int IN = 43;
-		public const int NOT = 44;
-		public const int NULL = 45;
-		public const int OF = 46;
-		public const int OR = 47;
-		public const int OTHERWISE = 48;
-		public const int OVERRIDE = 49;
-		public const int PASS = 50;
-		public const int NAMESPACE = 51;
-		public const int PARTIAL = 52;
-		public const int PUBLIC = 53;
-		public const int PROTECTED = 54;
-		public const int PRIVATE = 55;
-		public const int RAISE = 56;
-		public const int REF = 57;
-		public const int RETURN = 58;
-		public const int RETRY = 59;
-		public const int SET = 60;
-		public const int SELF = 61;
-		public const int SUPER = 62;
-		public const int STATIC = 63;
-		public const int SUCCESS = 64;
-		public const int STRUCT = 65;
-		public const int TRY = 66;
-		public const int TRANSIENT = 67;
-		public const int TRUE = 68;
-		public const int TYPEOF = 69;
-		public const int UNLESS = 70;
-		public const int VIRTUAL = 71;
-		public const int WHEN = 72;
-		public const int WHILE = 73;
-		public const int YIELD = 74;
-		public const int EOS = 75;
+		public const int EOL = 9;
+		public const int ABSTRACT = 10;
+		public const int AND = 11;
+		public const int AS = 12;
+		public const int AST = 13;
+		public const int BREAK = 14;
+		public const int CONTINUE = 15;
+		public const int CALLABLE = 16;
+		public const int CAST = 17;
+		public const int CHAR = 18;
+		public const int CLASS = 19;
+		public const int CONSTRUCTOR = 20;
+		public const int DEF = 21;
+		public const int DESTRUCTOR = 22;
+		public const int DO = 23;
+		public const int ELIF = 24;
+		public const int ELSE = 25;
+		public const int ENSURE = 26;
+		public const int ENUM = 27;
+		public const int EVENT = 28;
+		public const int EXCEPT = 29;
+		public const int FAILURE = 30;
+		public const int FINAL = 31;
+		public const int FROM = 32;
+		public const int FOR = 33;
+		public const int FALSE = 34;
+		public const int GET = 35;
+		public const int GIVEN = 36;
+		public const int GOTO = 37;
+		public const int IMPORT = 38;
+		public const int INTERFACE = 39;
+		public const int INTERNAL = 40;
+		public const int IS = 41;
+		public const int ISA = 42;
+		public const int IF = 43;
+		public const int IN = 44;
+		public const int NOT = 45;
+		public const int NULL = 46;
+		public const int OF = 47;
+		public const int OR = 48;
+		public const int OTHERWISE = 49;
+		public const int OVERRIDE = 50;
+		public const int PASS = 51;
+		public const int NAMESPACE = 52;
+		public const int PARTIAL = 53;
+		public const int PUBLIC = 54;
+		public const int PROTECTED = 55;
+		public const int PRIVATE = 56;
+		public const int RAISE = 57;
+		public const int REF = 58;
+		public const int RETURN = 59;
+		public const int RETRY = 60;
+		public const int SET = 61;
+		public const int SELF = 62;
+		public const int SUPER = 63;
+		public const int STATIC = 64;
+		public const int SUCCESS = 65;
+		public const int STRUCT = 66;
+		public const int TRY = 67;
+		public const int TRANSIENT = 68;
+		public const int TRUE = 69;
+		public const int TYPEOF = 70;
+		public const int UNLESS = 71;
+		public const int VIRTUAL = 72;
+		public const int WHEN = 73;
+		public const int WHILE = 74;
+		public const int YIELD = 75;
 		public const int TRIPLE_QUOTED_STRING = 76;
-		public const int DOUBLE_QUOTED_STRING = 77;
-		public const int SINGLE_QUOTED_STRING = 78;
-		public const int ID = 79;
-		public const int LPAREN = 80;
-		public const int RPAREN = 81;
-		public const int ASSIGN = 82;
-		public const int SUBTRACT = 83;
-		public const int LBRACK = 84;
-		public const int COMMA = 85;
-		public const int RBRACK = 86;
-		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 87;
-		public const int DOT = 88;
-		public const int COLON = 89;
-		public const int MULTIPLY = 90;
-		public const int BITWISE_OR = 91;
-		public const int LBRACE = 92;
-		public const int RBRACE = 93;
-		public const int INPLACE_BITWISE_OR = 94;
-		public const int INPLACE_BITWISE_AND = 95;
-		public const int INPLACE_SHIFT_LEFT = 96;
-		public const int INPLACE_SHIFT_RIGHT = 97;
-		public const int CMP_OPERATOR = 98;
-		public const int GREATER_THAN = 99;
-		public const int LESS_THAN = 100;
-		public const int ADD = 101;
-		public const int EXCLUSIVE_OR = 102;
-		public const int DIVISION = 103;
-		public const int MODULUS = 104;
-		public const int BITWISE_AND = 105;
-		public const int SHIFT_LEFT = 106;
-		public const int SHIFT_RIGHT = 107;
-		public const int EXPONENTIATION = 108;
-		public const int INCREMENT = 109;
-		public const int DECREMENT = 110;
-		public const int ONES_COMPLEMENT = 111;
-		public const int INT = 112;
-		public const int LONG = 113;
-		public const int RE_LITERAL = 114;
-		public const int DOUBLE = 115;
-		public const int FLOAT = 116;
-		public const int TIMESPAN = 117;
-		public const int LINE_CONTINUATION = 118;
-		public const int SL_COMMENT = 119;
-		public const int ML_COMMENT = 120;
-		public const int WS = 121;
-		public const int X_RE_LITERAL = 122;
-		public const int NEWLINE = 123;
-		public const int ESCAPED_EXPRESSION = 124;
-		public const int DQS_ESC = 125;
-		public const int SQS_ESC = 126;
-		public const int SESC = 127;
-		public const int RE_CHAR = 128;
-		public const int X_RE_CHAR = 129;
-		public const int RE_ESC = 130;
-		public const int DIGIT_GROUP = 131;
-		public const int REVERSE_DIGIT_GROUP = 132;
-		public const int ID_LETTER = 133;
-		public const int DIGIT = 134;
-		public const int HEXDIGIT = 135;
+		public const int EOS = 77;
+		public const int DOUBLE_QUOTED_STRING = 78;
+		public const int SINGLE_QUOTED_STRING = 79;
+		public const int ID = 80;
+		public const int LPAREN = 81;
+		public const int RPAREN = 82;
+		public const int ASSIGN = 83;
+		public const int SUBTRACT = 84;
+		public const int LBRACK = 85;
+		public const int COMMA = 86;
+		public const int RBRACK = 87;
+		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 88;
+		public const int DOT = 89;
+		public const int COLON = 90;
+		public const int MULTIPLY = 91;
+		public const int BITWISE_OR = 92;
+		public const int LBRACE = 93;
+		public const int RBRACE = 94;
+		public const int INPLACE_BITWISE_OR = 95;
+		public const int INPLACE_BITWISE_AND = 96;
+		public const int INPLACE_SHIFT_LEFT = 97;
+		public const int INPLACE_SHIFT_RIGHT = 98;
+		public const int CMP_OPERATOR = 99;
+		public const int GREATER_THAN = 100;
+		public const int LESS_THAN = 101;
+		public const int ADD = 102;
+		public const int EXCLUSIVE_OR = 103;
+		public const int DIVISION = 104;
+		public const int MODULUS = 105;
+		public const int BITWISE_AND = 106;
+		public const int SHIFT_LEFT = 107;
+		public const int SHIFT_RIGHT = 108;
+		public const int EXPONENTIATION = 109;
+		public const int INCREMENT = 110;
+		public const int DECREMENT = 111;
+		public const int ONES_COMPLEMENT = 112;
+		public const int INT = 113;
+		public const int LONG = 114;
+		public const int RE_LITERAL = 115;
+		public const int DOUBLE = 116;
+		public const int FLOAT = 117;
+		public const int TIMESPAN = 118;
+		public const int LINE_CONTINUATION = 119;
+		public const int SL_COMMENT = 120;
+		public const int ML_COMMENT = 121;
+		public const int WS = 122;
+		public const int X_RE_LITERAL = 123;
+		public const int NEWLINE = 124;
+		public const int ESCAPED_EXPRESSION = 125;
+		public const int DQS_ESC = 126;
+		public const int SQS_ESC = 127;
+		public const int SESC = 128;
+		public const int RE_CHAR = 129;
+		public const int X_RE_CHAR = 130;
+		public const int RE_ESC = 131;
+		public const int DIGIT_GROUP = 132;
+		public const int REVERSE_DIGIT_GROUP = 133;
+		public const int ID_PREFIX = 134;
+		public const int ID_LETTER = 135;
+		public const int DIGIT = 136;
+		public const int HEXDIGIT = 137;
 		
 		
 	protected int _skipWhitespaceRegion = 0;
@@ -278,72 +280,72 @@ using Boo.Lang.Parser.Util;
 			caseSensitiveLiterals = true;
 			setCaseSensitive(true);
 			literals = new Hashtable(100, (float) 0.4, null, Comparer.Default);
-			literals.Add("public", 53);
-			literals.Add("namespace", 51);
-			literals.Add("break", 13);
-			literals.Add("while", 73);
-			literals.Add("otherwise", 48);
-			literals.Add("raise", 56);
-			literals.Add("typeof", 69);
-			literals.Add("and", 10);
-			literals.Add("failure", 29);
-			literals.Add("not", 44);
-			literals.Add("return", 58);
-			literals.Add("pass", 50);
-			literals.Add("from", 31);
-			literals.Add("null", 45);
-			literals.Add("def", 20);
-			literals.Add("given", 35);
-			literals.Add("protected", 54);
-			literals.Add("ref", 57);
-			literals.Add("retry", 59);
-			literals.Add("when", 72);
-			literals.Add("class", 18);
-			literals.Add("do", 22);
-			literals.Add("except", 28);
-			literals.Add("event", 27);
-			literals.Add("ast", 12);
-			literals.Add("unless", 70);
-			literals.Add("super", 62);
-			literals.Add("set", 60);
-			literals.Add("transient", 67);
-			literals.Add("constructor", 19);
-			literals.Add("interface", 38);
-			literals.Add("of", 46);
-			literals.Add("is", 40);
-			literals.Add("internal", 39);
-			literals.Add("final", 30);
-			literals.Add("yield", 74);
-			literals.Add("or", 47);
-			literals.Add("destructor", 21);
-			literals.Add("if", 42);
-			literals.Add("success", 64);
-			literals.Add("override", 49);
-			literals.Add("as", 11);
-			literals.Add("try", 66);
-			literals.Add("goto", 36);
-			literals.Add("enum", 26);
-			literals.Add("isa", 41);
-			literals.Add("for", 32);
-			literals.Add("char", 17);
-			literals.Add("private", 55);
-			literals.Add("false", 33);
-			literals.Add("static", 63);
-			literals.Add("abstract", 9);
-			literals.Add("partial", 52);
-			literals.Add("callable", 15);
-			literals.Add("get", 34);
-			literals.Add("continue", 14);
-			literals.Add("cast", 16);
-			literals.Add("struct", 65);
-			literals.Add("else", 24);
-			literals.Add("import", 37);
-			literals.Add("elif", 23);
-			literals.Add("in", 43);
-			literals.Add("self", 61);
-			literals.Add("ensure", 25);
-			literals.Add("true", 68);
-			literals.Add("virtual", 71);
+			literals.Add("public", 54);
+			literals.Add("namespace", 52);
+			literals.Add("break", 14);
+			literals.Add("while", 74);
+			literals.Add("otherwise", 49);
+			literals.Add("raise", 57);
+			literals.Add("typeof", 70);
+			literals.Add("and", 11);
+			literals.Add("failure", 30);
+			literals.Add("not", 45);
+			literals.Add("return", 59);
+			literals.Add("pass", 51);
+			literals.Add("from", 32);
+			literals.Add("null", 46);
+			literals.Add("def", 21);
+			literals.Add("given", 36);
+			literals.Add("protected", 55);
+			literals.Add("ref", 58);
+			literals.Add("retry", 60);
+			literals.Add("when", 73);
+			literals.Add("class", 19);
+			literals.Add("do", 23);
+			literals.Add("except", 29);
+			literals.Add("event", 28);
+			literals.Add("ast", 13);
+			literals.Add("unless", 71);
+			literals.Add("super", 63);
+			literals.Add("set", 61);
+			literals.Add("transient", 68);
+			literals.Add("constructor", 20);
+			literals.Add("interface", 39);
+			literals.Add("of", 47);
+			literals.Add("is", 41);
+			literals.Add("internal", 40);
+			literals.Add("final", 31);
+			literals.Add("yield", 75);
+			literals.Add("or", 48);
+			literals.Add("destructor", 22);
+			literals.Add("if", 43);
+			literals.Add("success", 65);
+			literals.Add("override", 50);
+			literals.Add("as", 12);
+			literals.Add("try", 67);
+			literals.Add("goto", 37);
+			literals.Add("enum", 27);
+			literals.Add("isa", 42);
+			literals.Add("for", 33);
+			literals.Add("char", 18);
+			literals.Add("private", 56);
+			literals.Add("false", 34);
+			literals.Add("static", 64);
+			literals.Add("abstract", 10);
+			literals.Add("partial", 53);
+			literals.Add("callable", 16);
+			literals.Add("get", 35);
+			literals.Add("continue", 15);
+			literals.Add("cast", 17);
+			literals.Add("struct", 66);
+			literals.Add("else", 25);
+			literals.Add("import", 38);
+			literals.Add("elif", 24);
+			literals.Add("in", 44);
+			literals.Add("self", 62);
+			literals.Add("ensure", 26);
+			literals.Add("true", 69);
+			literals.Add("virtual", 72);
 		}
 		
 		override public IToken nextToken()			//throws TokenStreamException
@@ -361,25 +363,6 @@ tryAgain:
 					{
 						switch ( cached_LA1 )
 						{
-						case 'A':  case 'B':  case 'C':  case 'D':
-						case 'E':  case 'F':  case 'G':  case 'H':
-						case 'I':  case 'J':  case 'K':  case 'L':
-						case 'M':  case 'N':  case 'O':  case 'P':
-						case 'Q':  case 'R':  case 'S':  case 'T':
-						case 'U':  case 'V':  case 'W':  case 'X':
-						case 'Y':  case 'Z':  case '_':  case 'a':
-						case 'b':  case 'c':  case 'd':  case 'e':
-						case 'f':  case 'g':  case 'h':  case 'i':
-						case 'j':  case 'k':  case 'l':  case 'm':
-						case 'n':  case 'o':  case 'p':  case 'q':
-						case 'r':  case 's':  case 't':  case 'u':
-						case 'v':  case 'w':  case 'x':  case 'y':
-						case 'z':
-						{
-							mID(true);
-							theRetToken = returnToken_;
-							break;
-						}
 						case '\\':
 						{
 							mLINE_CONTINUATION(true);
@@ -521,12 +504,6 @@ tryAgain:
 							theRetToken = returnToken_;
 							break;
 						}
-						case '@':
-						{
-							mX_RE_LITERAL(true);
-							theRetToken = returnToken_;
-							break;
-						}
 						default:
 							if ((cached_LA1=='<') && (cached_LA2=='<') && (LA(3)=='='))
 							{
@@ -561,6 +538,14 @@ tryAgain:
 								mCMP_OPERATOR(true);
 								theRetToken = returnToken_;
 							}
+							else if ((cached_LA1=='@') && (cached_LA2=='/')) {
+								mX_RE_LITERAL(true);
+								theRetToken = returnToken_;
+							}
+							else if ((tokenSet_0_.member(cached_LA1)) && (true)) {
+								mID(true);
+								theRetToken = returnToken_;
+							}
 							else if ((cached_LA1=='+') && (true)) {
 								mADD(true);
 								theRetToken = returnToken_;
@@ -612,44 +597,37 @@ tryAgain:
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = ID;
 		
+		{
+			if ((cached_LA1=='$'||cached_LA1=='?'||cached_LA1=='@'))
+			{
+				mID_PREFIX(false);
+			}
+			else if ((tokenSet_1_.member(cached_LA1))) {
+			}
+			else
+			{
+				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+			}
+			
+		}
 		mID_LETTER(false);
 		{    // ( ... )*
 			for (;;)
 			{
-				switch ( cached_LA1 )
-				{
-				case 'A':  case 'B':  case 'C':  case 'D':
-				case 'E':  case 'F':  case 'G':  case 'H':
-				case 'I':  case 'J':  case 'K':  case 'L':
-				case 'M':  case 'N':  case 'O':  case 'P':
-				case 'Q':  case 'R':  case 'S':  case 'T':
-				case 'U':  case 'V':  case 'W':  case 'X':
-				case 'Y':  case 'Z':  case '_':  case 'a':
-				case 'b':  case 'c':  case 'd':  case 'e':
-				case 'f':  case 'g':  case 'h':  case 'i':
-				case 'j':  case 'k':  case 'l':  case 'm':
-				case 'n':  case 'o':  case 'p':  case 'q':
-				case 'r':  case 's':  case 't':  case 'u':
-				case 'v':  case 'w':  case 'x':  case 'y':
-				case 'z':
+				if ((tokenSet_1_.member(cached_LA1)))
 				{
 					mID_LETTER(false);
-					break;
 				}
-				case '0':  case '1':  case '2':  case '3':
-				case '4':  case '5':  case '6':  case '7':
-				case '8':  case '9':
-				{
+				else if (((cached_LA1 >= '0' && cached_LA1 <= '9'))) {
 					mDIGIT(false);
-					break;
 				}
-				default:
+				else
 				{
-					goto _loop529_breakloop;
+					goto _loop556_breakloop;
 				}
-				 }
+				
 			}
-_loop529_breakloop:			;
+_loop556_breakloop:			;
 		}    // ( ... )*
 		_ttype = testLiteralsTable(_ttype);
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -660,6 +638,41 @@ _loop529_breakloop:			;
 		returnToken_ = _token;
 	}
 	
+	protected void mID_PREFIX(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = ID_PREFIX;
+		
+		switch ( cached_LA1 )
+		{
+		case '$':
+		{
+			match('$');
+			break;
+		}
+		case '@':
+		{
+			match('@');
+			break;
+		}
+		case '?':
+		{
+			match('?');
+			break;
+		}
+		default:
+		{
+			throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+		}
+		 }
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
 	protected void mID_LETTER(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
 {
 		int _ttype; IToken _token=null; int _begin=text.Length;
@@ -696,10 +709,15 @@ _loop529_breakloop:			;
 				break;
 			}
 			default:
+				if ((((cached_LA1 >= '\u0080' && cached_LA1 <= '\ufffe')))&&(System.Char.IsLetter(LA(1))))
+				{
+					matchRange('\u0080','\uFFFE');
+				}
+			else
 			{
 				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
 			}
-			 }
+			break; }
 		}
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -802,21 +820,21 @@ _loop529_breakloop:			;
 			{
 				match("0x");
 				{ // ( ... )+
-					int _cnt534=0;
+					int _cnt561=0;
 					for (;;)
 					{
-						if ((tokenSet_0_.member(cached_LA1)))
+						if ((tokenSet_2_.member(cached_LA1)))
 						{
 							mHEXDIGIT(false);
 						}
 						else
 						{
-							if (_cnt534 >= 1) { goto _loop534_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt561 >= 1) { goto _loop561_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt534++;
+						_cnt561++;
 					}
-_loop534_breakloop:					;
+_loop561_breakloop:					;
 				}    // ( ... )+
 			}
 			{
@@ -1206,11 +1224,11 @@ _loop534_breakloop:					;
 				}
 				default:
 				{
-					goto _loop689_breakloop;
+					goto _loop716_breakloop;
 				}
 				 }
 			}
-_loop689_breakloop:			;
+_loop716_breakloop:			;
 		}    // ( ... )*
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1226,7 +1244,7 @@ _loop689_breakloop:			;
 		_ttype = REVERSE_DIGIT_GROUP;
 		
 		{ // ( ... )+
-			int _cnt693=0;
+			int _cnt720=0;
 			for (;;)
 			{
 				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
@@ -1252,12 +1270,12 @@ _loop689_breakloop:			;
 				}
 				else
 				{
-					if (_cnt693 >= 1) { goto _loop693_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt720 >= 1) { goto _loop720_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt693++;
+				_cnt720++;
 			}
-_loop693_breakloop:			;
+_loop720_breakloop:			;
 		}    // ( ... )+
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1582,11 +1600,11 @@ _loop693_breakloop:			;
 			EnterSkipWhitespaceRegion();
 		}
 		{
-			bool synPredMatched578 = false;
+			bool synPredMatched605 = false;
 			if (((cached_LA1=='a')))
 			{
-				int _m578 = mark();
-				synPredMatched578 = true;
+				int _m605 = mark();
+				synPredMatched605 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1595,12 +1613,12 @@ _loop693_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched578 = false;
+					synPredMatched605 = false;
 				}
-				rewind(_m578);
+				rewind(_m605);
 				inputState.guessing--;
 			}
-			if ( synPredMatched578 )
+			if ( synPredMatched605 )
 			{
 				match("assembly:");
 				if (0==inputState.guessing)
@@ -1820,11 +1838,11 @@ _loop693_breakloop:			;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched596 = false;
+		bool synPredMatched623 = false;
 		if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 		{
-			int _m596 = mark();
-			synPredMatched596 = true;
+			int _m623 = mark();
+			synPredMatched623 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1833,12 +1851,12 @@ _loop693_breakloop:			;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched596 = false;
+				synPredMatched623 = false;
 			}
-			rewind(_m596);
+			rewind(_m623);
 			inputState.guessing--;
 		}
-		if ( synPredMatched596 )
+		if ( synPredMatched623 )
 		{
 			mML_COMMENT(false);
 			if (0==inputState.guessing)
@@ -1847,11 +1865,11 @@ _loop693_breakloop:			;
 			}
 		}
 		else {
-			bool synPredMatched598 = false;
-			if (((cached_LA1=='/') && (tokenSet_1_.member(cached_LA2)) && (tokenSet_2_.member(LA(3)))))
+			bool synPredMatched625 = false;
+			if (((cached_LA1=='/') && (tokenSet_3_.member(cached_LA2)) && (tokenSet_4_.member(LA(3)))))
 			{
-				int _m598 = mark();
-				synPredMatched598 = true;
+				int _m625 = mark();
+				synPredMatched625 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1860,12 +1878,12 @@ _loop693_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched598 = false;
+					synPredMatched625 = false;
 				}
-				rewind(_m598);
+				rewind(_m625);
 				inputState.guessing--;
 			}
-			if ( synPredMatched598 )
+			if ( synPredMatched625 )
 			{
 				mRE_LITERAL(false);
 				if (0==inputState.guessing)
@@ -1885,19 +1903,19 @@ _loop693_breakloop:			;
 							{    // ( ... )*
 								for (;;)
 								{
-									if ((tokenSet_3_.member(cached_LA1)))
+									if ((tokenSet_5_.member(cached_LA1)))
 									{
 										{
-											match(tokenSet_3_);
+											match(tokenSet_5_);
 										}
 									}
 									else
 									{
-										goto _loop603_breakloop;
+										goto _loop630_breakloop;
 									}
 									
 								}
-_loop603_breakloop:								;
+_loop630_breakloop:								;
 							}    // ( ... )*
 							if (0==inputState.guessing)
 							{
@@ -1950,11 +1968,11 @@ _loop603_breakloop:								;
 					match('*');
 				}
 				else {
-					bool synPredMatched644 = false;
+					bool synPredMatched671 = false;
 					if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m644 = mark();
-						synPredMatched644 = true;
+						int _m671 = mark();
+						synPredMatched671 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -1963,18 +1981,18 @@ _loop603_breakloop:								;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched644 = false;
+							synPredMatched671 = false;
 						}
-						rewind(_m644);
+						rewind(_m671);
 						inputState.guessing--;
 					}
-					if ( synPredMatched644 )
+					if ( synPredMatched671 )
 					{
 						mML_COMMENT(false);
 					}
-					else if ((tokenSet_4_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
+					else if ((tokenSet_6_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
 						{
-							match(tokenSet_4_);
+							match(tokenSet_6_);
 						}
 					}
 					else if ((cached_LA1=='\n'||cached_LA1=='\r')) {
@@ -1982,11 +2000,11 @@ _loop603_breakloop:								;
 					}
 					else
 					{
-						goto _loop646_breakloop;
+						goto _loop673_breakloop;
 					}
 					}
 				}
-_loop646_breakloop:				;
+_loop673_breakloop:				;
 			}    // ( ... )*
 			match("*/");
 			if (0==inputState.guessing)
@@ -2008,21 +2026,21 @@ _loop646_breakloop:				;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt675=0;
+			int _cnt702=0;
 			for (;;)
 			{
-				if ((tokenSet_1_.member(cached_LA1)))
+				if ((tokenSet_3_.member(cached_LA1)))
 				{
 					mRE_CHAR(false);
 				}
 				else
 				{
-					if (_cnt675 >= 1) { goto _loop675_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt702 >= 1) { goto _loop702_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt675++;
+				_cnt702++;
 			}
-_loop675_breakloop:			;
+_loop702_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -2241,12 +2259,12 @@ _loop675_breakloop:			;
 			for (;;)
 			{
 				// nongreedy exit test
-				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop624_breakloop;
-				bool synPredMatched620 = false;
+				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop651_breakloop;
+				bool synPredMatched647 = false;
 				if (((cached_LA1=='$') && (cached_LA2=='{') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 				{
-					int _m620 = mark();
-					synPredMatched620 = true;
+					int _m647 = mark();
+					synPredMatched647 = true;
 					inputState.guessing++;
 					try {
 						{
@@ -2255,12 +2273,12 @@ _loop675_breakloop:			;
 					}
 					catch (RecognitionException)
 					{
-						synPredMatched620 = false;
+						synPredMatched647 = false;
 					}
-					rewind(_m620);
+					rewind(_m647);
 					inputState.guessing--;
 				}
-				if ( synPredMatched620 )
+				if ( synPredMatched647 )
 				{
 					if (0==inputState.guessing)
 					{
@@ -2272,11 +2290,11 @@ _loop675_breakloop:			;
 					mESCAPED_EXPRESSION(false);
 				}
 				else {
-					bool synPredMatched622 = false;
+					bool synPredMatched649 = false;
 					if (((cached_LA1=='\\') && (cached_LA2=='$') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m622 = mark();
-						synPredMatched622 = true;
+						int _m649 = mark();
+						synPredMatched649 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -2285,21 +2303,21 @@ _loop675_breakloop:			;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched622 = false;
+							synPredMatched649 = false;
 						}
-						rewind(_m622);
+						rewind(_m649);
 						inputState.guessing--;
 					}
-					if ( synPredMatched622 )
+					if ( synPredMatched649 )
 					{
 						_saveIndex = text.Length;
 						match('\\');
 						text.Length = _saveIndex;
 						match('$');
 					}
-					else if ((tokenSet_3_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
+					else if ((tokenSet_5_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
 						{
-							match(tokenSet_3_);
+							match(tokenSet_5_);
 						}
 					}
 					else if ((cached_LA1=='\n'||cached_LA1=='\r')) {
@@ -2307,11 +2325,11 @@ _loop675_breakloop:			;
 					}
 					else
 					{
-						goto _loop624_breakloop;
+						goto _loop651_breakloop;
 					}
 					}
 				}
-_loop624_breakloop:				;
+_loop651_breakloop:				;
 			}    // ( ... )*
 			_saveIndex = text.Length;
 			match("\"\"\"");
@@ -2374,16 +2392,16 @@ _loop624_breakloop:				;
 					_ttype = TRIPLE_QUOTED_STRING;
 				}
 			}
-			else if ((tokenSet_3_.member(cached_LA1)) && (true) && (true)) {
+			else if ((tokenSet_5_.member(cached_LA1)) && (true) && (true)) {
 				{
 					{    // ( ... )*
 						for (;;)
 						{
-							bool synPredMatched630 = false;
-							if (((cached_LA1=='$') && (cached_LA2=='{') && (tokenSet_3_.member(LA(3)))))
+							bool synPredMatched657 = false;
+							if (((cached_LA1=='$') && (cached_LA2=='{') && (tokenSet_5_.member(LA(3)))))
 							{
-								int _m630 = mark();
-								synPredMatched630 = true;
+								int _m657 = mark();
+								synPredMatched657 = true;
 								inputState.guessing++;
 								try {
 									{
@@ -2392,12 +2410,12 @@ _loop624_breakloop:				;
 								}
 								catch (RecognitionException)
 								{
-									synPredMatched630 = false;
+									synPredMatched657 = false;
 								}
-								rewind(_m630);
+								rewind(_m657);
 								inputState.guessing--;
 							}
-							if ( synPredMatched630 )
+							if ( synPredMatched657 )
 							{
 								if (0==inputState.guessing)
 								{
@@ -2408,9 +2426,9 @@ _loop624_breakloop:				;
 								}
 								mESCAPED_EXPRESSION(false);
 							}
-							else if ((tokenSet_5_.member(cached_LA1)) && (tokenSet_3_.member(cached_LA2)) && (true)) {
+							else if ((tokenSet_7_.member(cached_LA1)) && (tokenSet_5_.member(cached_LA2)) && (true)) {
 								{
-									match(tokenSet_5_);
+									match(tokenSet_7_);
 								}
 							}
 							else if ((cached_LA1=='\\')) {
@@ -2418,11 +2436,11 @@ _loop624_breakloop:				;
 							}
 							else
 							{
-								goto _loop632_breakloop;
+								goto _loop659_breakloop;
 							}
 							
 						}
-_loop632_breakloop:						;
+_loop659_breakloop:						;
 					}    // ( ... )*
 					_saveIndex = text.Length;
 					match('"');
@@ -2514,18 +2532,18 @@ _loop632_breakloop:						;
 				{
 					mSQS_ESC(false);
 				}
-				else if ((tokenSet_6_.member(cached_LA1))) {
+				else if ((tokenSet_8_.member(cached_LA1))) {
 					{
-						match(tokenSet_6_);
+						match(tokenSet_8_);
 					}
 				}
 				else
 				{
-					goto _loop636_breakloop;
+					goto _loop663_breakloop;
 				}
 				
 			}
-_loop636_breakloop:			;
+_loop663_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2585,19 +2603,19 @@ _loop636_breakloop:			;
 		{    // ( ... )*
 			for (;;)
 			{
-				if ((tokenSet_3_.member(cached_LA1)))
+				if ((tokenSet_5_.member(cached_LA1)))
 				{
 					{
-						match(tokenSet_3_);
+						match(tokenSet_5_);
 					}
 				}
 				else
 				{
-					goto _loop640_breakloop;
+					goto _loop667_breakloop;
 				}
 				
 			}
-_loop640_breakloop:			;
+_loop667_breakloop:			;
 		}    // ( ... )*
 		if (0==inputState.guessing)
 		{
@@ -2617,7 +2635,7 @@ _loop640_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt649=0;
+			int _cnt676=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -2644,12 +2662,12 @@ _loop640_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt649 >= 1) { goto _loop649_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt676 >= 1) { goto _loop676_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt649++;
+				_cnt676++;
 			}
-_loop649_breakloop:			;
+_loop676_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -2693,21 +2711,21 @@ _loop649_breakloop:			;
 		text.Length = _saveIndex;
 		match('/');
 		{ // ( ... )+
-			int _cnt653=0;
+			int _cnt680=0;
 			for (;;)
 			{
-				if ((tokenSet_7_.member(cached_LA1)))
+				if ((tokenSet_9_.member(cached_LA1)))
 				{
 					mX_RE_CHAR(false);
 				}
 				else
 				{
-					if (_cnt653 >= 1) { goto _loop653_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt680 >= 1) { goto _loop680_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt653++;
+				_cnt680++;
 			}
-_loop653_breakloop:			;
+_loop680_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (0==inputState.guessing)
@@ -2740,7 +2758,7 @@ _loop653_breakloop:			;
 			break;
 		}
 		default:
-			if ((tokenSet_1_.member(cached_LA1)))
+			if ((tokenSet_3_.member(cached_LA1)))
 			{
 				mRE_CHAR(false);
 			}
@@ -2920,9 +2938,9 @@ _loop653_breakloop:			;
 		{
 			mRE_ESC(false);
 		}
-		else if ((tokenSet_8_.member(cached_LA1))) {
+		else if ((tokenSet_10_.member(cached_LA1))) {
 			{
-				match(tokenSet_8_);
+				match(tokenSet_10_);
 			}
 		}
 		else
@@ -3070,21 +3088,21 @@ _loop653_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt683=0;
+					int _cnt710=0;
 					for (;;)
 					{
-						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_3_.member(cached_LA2)) && (true))
+						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_5_.member(cached_LA2)) && (true))
 						{
 							mDIGIT(false);
 						}
 						else
 						{
-							if (_cnt683 >= 1) { goto _loop683_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt710 >= 1) { goto _loop710_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt683++;
+						_cnt710++;
 					}
-_loop683_breakloop:					;
+_loop710_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
@@ -3199,6 +3217,28 @@ _loop683_breakloop:					;
 	
 	
 	private static long[] mk_tokenSet_0_()
+	{
+		long[] data = new long[3072];
+		data[0]=-9223371968135299072L;
+		data[1]=576460745995190271L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
+	private static long[] mk_tokenSet_1_()
+	{
+		long[] data = new long[3072];
+		data[0]=0L;
+		data[1]=576460745995190270L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
+	private static long[] mk_tokenSet_2_()
 	{
 		long[] data = new long[1025];
 		data[0]=287948901175001088L;
@@ -3206,31 +3246,11 @@ _loop683_breakloop:					;
 		for (int i = 2; i<=1024; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
-	private static long[] mk_tokenSet_1_()
-	{
-		long[] data = new long[2048];
-		data[0]=-140741783332360L;
-		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
-		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
-		return data;
-	}
-	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
-	private static long[] mk_tokenSet_2_()
-	{
-		long[] data = new long[2048];
-		data[0]=-4294977032L;
-		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
-		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
-		return data;
-	}
 	public static readonly BitSet tokenSet_2_ = new BitSet(mk_tokenSet_2_());
 	private static long[] mk_tokenSet_3_()
 	{
 		long[] data = new long[2048];
-		data[0]=-9224L;
+		data[0]=-140741783332360L;
 		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
@@ -3240,7 +3260,7 @@ _loop683_breakloop:					;
 	private static long[] mk_tokenSet_4_()
 	{
 		long[] data = new long[2048];
-		data[0]=-4398046520328L;
+		data[0]=-4294977032L;
 		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
@@ -3248,6 +3268,26 @@ _loop683_breakloop:					;
 	}
 	public static readonly BitSet tokenSet_4_ = new BitSet(mk_tokenSet_4_());
 	private static long[] mk_tokenSet_5_()
+	{
+		long[] data = new long[2048];
+		data[0]=-9224L;
+		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_5_ = new BitSet(mk_tokenSet_5_());
+	private static long[] mk_tokenSet_6_()
+	{
+		long[] data = new long[2048];
+		data[0]=-4398046520328L;
+		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_6_ = new BitSet(mk_tokenSet_6_());
+	private static long[] mk_tokenSet_7_()
 	{
 		long[] data = new long[2048];
 		data[0]=-17179878408L;
@@ -3257,8 +3297,8 @@ _loop683_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_5_ = new BitSet(mk_tokenSet_5_());
-	private static long[] mk_tokenSet_6_()
+	public static readonly BitSet tokenSet_7_ = new BitSet(mk_tokenSet_7_());
+	private static long[] mk_tokenSet_8_()
 	{
 		long[] data = new long[2048];
 		data[0]=-549755823112L;
@@ -3268,8 +3308,8 @@ _loop683_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_6_ = new BitSet(mk_tokenSet_6_());
-	private static long[] mk_tokenSet_7_()
+	public static readonly BitSet tokenSet_8_ = new BitSet(mk_tokenSet_8_());
+	private static long[] mk_tokenSet_9_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140737488364552L;
@@ -3278,8 +3318,8 @@ _loop683_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_7_ = new BitSet(mk_tokenSet_7_());
-	private static long[] mk_tokenSet_8_()
+	public static readonly BitSet tokenSet_9_ = new BitSet(mk_tokenSet_9_());
+	private static long[] mk_tokenSet_10_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140741783332360L;
@@ -3289,7 +3329,7 @@ _loop683_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_8_ = new BitSet(mk_tokenSet_8_());
+	public static readonly BitSet tokenSet_10_ = new BitSet(mk_tokenSet_10_());
 	
 }
 }
