@@ -27,7 +27,7 @@
 #endregion
 
 
-// $ANTLR 2.7.5 (20050517): "wsabooel.g" -> "WSABooExpressionLexer.cs"$
+// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/wsabooel.g" -> "WSABooExpressionLexer.cs"$
 
 namespace Boo.Lang.Parser
 {
@@ -131,8 +131,8 @@ namespace Boo.Lang.Parser
 		public const int WHEN = 69;
 		public const int WHILE = 70;
 		public const int YIELD = 71;
-		public const int EOS = 72;
-		public const int TRIPLE_QUOTED_STRING = 73;
+		public const int TRIPLE_QUOTED_STRING = 72;
+		public const int EOS = 73;
 		public const int DOUBLE_QUOTED_STRING = 74;
 		public const int SINGLE_QUOTED_STRING = 75;
 		public const int ID = 76;
@@ -190,9 +190,10 @@ namespace Boo.Lang.Parser
 		public const int RE_ESC = 128;
 		public const int DIGIT_GROUP = 129;
 		public const int REVERSE_DIGIT_GROUP = 130;
-		public const int ID_LETTER = 131;
-		public const int DIGIT = 132;
-		public const int HEXDIGIT = 133;
+		public const int ID_PREFIX = 131;
+		public const int ID_LETTER = 132;
+		public const int DIGIT = 133;
+		public const int HEXDIGIT = 134;
 		
 		
 	
@@ -308,25 +309,6 @@ tryAgain:
 					{
 						switch ( cached_LA1 )
 						{
-						case 'A':  case 'B':  case 'C':  case 'D':
-						case 'E':  case 'F':  case 'G':  case 'H':
-						case 'I':  case 'J':  case 'K':  case 'L':
-						case 'M':  case 'N':  case 'O':  case 'P':
-						case 'Q':  case 'R':  case 'S':  case 'T':
-						case 'U':  case 'V':  case 'W':  case 'X':
-						case 'Y':  case 'Z':  case '_':  case 'a':
-						case 'b':  case 'c':  case 'd':  case 'e':
-						case 'f':  case 'g':  case 'h':  case 'i':
-						case 'j':  case 'k':  case 'l':  case 'm':
-						case 'n':  case 'o':  case 'p':  case 'q':
-						case 'r':  case 's':  case 't':  case 'u':
-						case 'v':  case 'w':  case 'x':  case 'y':
-						case 'z':
-						{
-							mID(true);
-							theRetToken = returnToken_;
-							break;
-						}
 						case '0':  case '1':  case '2':  case '3':
 						case '4':  case '5':  case '6':  case '7':
 						case '8':  case '9':
@@ -479,6 +461,10 @@ tryAgain:
 								mCMP_OPERATOR(true);
 								theRetToken = returnToken_;
 							}
+							else if ((tokenSet_0_.member(cached_LA1))) {
+								mID(true);
+								theRetToken = returnToken_;
+							}
 							else if ((cached_LA1=='+') && (true)) {
 								mADD(true);
 								theRetToken = returnToken_;
@@ -526,44 +512,37 @@ tryAgain:
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = ID;
 		
+		{
+			if ((cached_LA1=='$'||cached_LA1=='?'||cached_LA1=='@'))
+			{
+				mID_PREFIX(false);
+			}
+			else if ((tokenSet_1_.member(cached_LA1))) {
+			}
+			else
+			{
+				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+			}
+			
+		}
 		mID_LETTER(false);
 		{    // ( ... )*
 			for (;;)
 			{
-				switch ( cached_LA1 )
-				{
-				case 'A':  case 'B':  case 'C':  case 'D':
-				case 'E':  case 'F':  case 'G':  case 'H':
-				case 'I':  case 'J':  case 'K':  case 'L':
-				case 'M':  case 'N':  case 'O':  case 'P':
-				case 'Q':  case 'R':  case 'S':  case 'T':
-				case 'U':  case 'V':  case 'W':  case 'X':
-				case 'Y':  case 'Z':  case '_':  case 'a':
-				case 'b':  case 'c':  case 'd':  case 'e':
-				case 'f':  case 'g':  case 'h':  case 'i':
-				case 'j':  case 'k':  case 'l':  case 'm':
-				case 'n':  case 'o':  case 'p':  case 'q':
-				case 'r':  case 's':  case 't':  case 'u':
-				case 'v':  case 'w':  case 'x':  case 'y':
-				case 'z':
+				if ((tokenSet_1_.member(cached_LA1)))
 				{
 					mID_LETTER(false);
-					break;
 				}
-				case '0':  case '1':  case '2':  case '3':
-				case '4':  case '5':  case '6':  case '7':
-				case '8':  case '9':
-				{
+				else if (((cached_LA1 >= '0' && cached_LA1 <= '9'))) {
 					mDIGIT(false);
-					break;
 				}
-				default:
+				else
 				{
-					goto _loop3_breakloop;
+					goto _loop4_breakloop;
 				}
-				 }
+				
 			}
-_loop3_breakloop:			;
+_loop4_breakloop:			;
 		}    // ( ... )*
 		_ttype = testLiteralsTable(_ttype);
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -574,6 +553,41 @@ _loop3_breakloop:			;
 		returnToken_ = _token;
 	}
 	
+	protected void mID_PREFIX(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = ID_PREFIX;
+		
+		switch ( cached_LA1 )
+		{
+		case '$':
+		{
+			match('$');
+			break;
+		}
+		case '@':
+		{
+			match('@');
+			break;
+		}
+		case '?':
+		{
+			match('?');
+			break;
+		}
+		default:
+		{
+			throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+		}
+		 }
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
 	protected void mID_LETTER(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
 {
 		int _ttype; IToken _token=null; int _begin=text.Length;
@@ -610,10 +624,15 @@ _loop3_breakloop:			;
 				break;
 			}
 			default:
+				if ((((cached_LA1 >= '\u0080' && cached_LA1 <= '\ufffe')))&&(System.Char.IsLetter(LA(1))))
+				{
+					matchRange('\u0080','\uFFFE');
+				}
+			else
 			{
 				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
 			}
-			 }
+			break; }
 		}
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -647,21 +666,21 @@ _loop3_breakloop:			;
 			{
 				match("0x");
 				{ // ( ... )+
-					int _cnt7=0;
+					int _cnt8=0;
 					for (;;)
 					{
-						if ((tokenSet_0_.member(cached_LA1)))
+						if ((tokenSet_2_.member(cached_LA1)))
 						{
 							mHEXDIGIT(false);
 						}
 						else
 						{
-							if (_cnt7 >= 1) { goto _loop7_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt8 >= 1) { goto _loop8_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt7++;
+						_cnt8++;
 					}
-_loop7_breakloop:					;
+_loop8_breakloop:					;
 				}    // ( ... )+
 			}
 			{
@@ -1051,11 +1070,11 @@ _loop7_breakloop:					;
 				}
 				default:
 				{
-					goto _loop116_breakloop;
+					goto _loop117_breakloop;
 				}
 				 }
 			}
-_loop116_breakloop:			;
+_loop117_breakloop:			;
 		}    // ( ... )*
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1071,7 +1090,7 @@ _loop116_breakloop:			;
 		_ttype = REVERSE_DIGIT_GROUP;
 		
 		{ // ( ... )+
-			int _cnt120=0;
+			int _cnt121=0;
 			for (;;)
 			{
 				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
@@ -1097,12 +1116,12 @@ _loop116_breakloop:			;
 				}
 				else
 				{
-					if (_cnt120 >= 1) { goto _loop120_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt121 >= 1) { goto _loop121_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt120++;
+				_cnt121++;
 			}
-_loop120_breakloop:			;
+_loop121_breakloop:			;
 		}    // ( ... )+
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1583,11 +1602,11 @@ _loop120_breakloop:			;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched63 = false;
-		if (((cached_LA1=='/') && (tokenSet_1_.member(cached_LA2)) && (tokenSet_2_.member(LA(3)))))
+		bool synPredMatched64 = false;
+		if (((cached_LA1=='/') && (tokenSet_3_.member(cached_LA2)) && (tokenSet_4_.member(LA(3)))))
 		{
-			int _m63 = mark();
-			synPredMatched63 = true;
+			int _m64 = mark();
+			synPredMatched64 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1596,12 +1615,12 @@ _loop120_breakloop:			;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched63 = false;
+				synPredMatched64 = false;
 			}
-			rewind(_m63);
+			rewind(_m64);
 			inputState.guessing--;
 		}
-		if ( synPredMatched63 )
+		if ( synPredMatched64 )
 		{
 			mRE_LITERAL(false);
 			if (0==inputState.guessing)
@@ -1645,21 +1664,21 @@ _loop120_breakloop:			;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt103=0;
+			int _cnt104=0;
 			for (;;)
 			{
-				if ((tokenSet_1_.member(cached_LA1)))
+				if ((tokenSet_3_.member(cached_LA1)))
 				{
 					mRE_CHAR(false);
 				}
 				else
 				{
-					if (_cnt103 >= 1) { goto _loop103_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt104 >= 1) { goto _loop104_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt103++;
+				_cnt104++;
 			}
-_loop103_breakloop:			;
+_loop104_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -1857,7 +1876,7 @@ _loop103_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt82=0;
+			int _cnt83=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -1918,12 +1937,12 @@ _loop103_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt82 >= 1) { goto _loop82_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt83 >= 1) { goto _loop83_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt82++;
+				_cnt83++;
 			}
-_loop82_breakloop:			;
+_loop83_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -1953,18 +1972,18 @@ _loop82_breakloop:			;
 				{
 					mSQS_ESC(false);
 				}
-				else if ((tokenSet_3_.member(cached_LA1))) {
+				else if ((tokenSet_5_.member(cached_LA1))) {
 					{
-						match(tokenSet_3_);
+						match(tokenSet_5_);
 					}
 				}
 				else
 				{
-					goto _loop86_breakloop;
+					goto _loop87_breakloop;
 				}
 				
 			}
-_loop86_breakloop:			;
+_loop87_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2221,9 +2240,9 @@ _loop86_breakloop:			;
 		{
 			mRE_ESC(false);
 		}
-		else if ((tokenSet_4_.member(cached_LA1))) {
+		else if ((tokenSet_6_.member(cached_LA1))) {
 			{
-				match(tokenSet_4_);
+				match(tokenSet_6_);
 			}
 		}
 		else
@@ -2371,21 +2390,21 @@ _loop86_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt110=0;
+					int _cnt111=0;
 					for (;;)
 					{
-						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_2_.member(cached_LA2)) && (true))
+						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_4_.member(cached_LA2)) && (true))
 						{
 							mDIGIT(false);
 						}
 						else
 						{
-							if (_cnt110 >= 1) { goto _loop110_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt111 >= 1) { goto _loop111_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt110++;
+						_cnt111++;
 					}
-_loop110_breakloop:					;
+_loop111_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
@@ -2500,6 +2519,28 @@ _loop110_breakloop:					;
 	
 	
 	private static long[] mk_tokenSet_0_()
+	{
+		long[] data = new long[3072];
+		data[0]=-9223371968135299072L;
+		data[1]=576460745995190271L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
+	private static long[] mk_tokenSet_1_()
+	{
+		long[] data = new long[3072];
+		data[0]=0L;
+		data[1]=576460745995190270L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
+	private static long[] mk_tokenSet_2_()
 	{
 		long[] data = new long[1025];
 		data[0]=287948901175001088L;
@@ -2507,8 +2548,8 @@ _loop110_breakloop:					;
 		for (int i = 2; i<=1024; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
-	private static long[] mk_tokenSet_1_()
+	public static readonly BitSet tokenSet_2_ = new BitSet(mk_tokenSet_2_());
+	private static long[] mk_tokenSet_3_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140741783332360L;
@@ -2517,8 +2558,8 @@ _loop110_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
-	private static long[] mk_tokenSet_2_()
+	public static readonly BitSet tokenSet_3_ = new BitSet(mk_tokenSet_3_());
+	private static long[] mk_tokenSet_4_()
 	{
 		long[] data = new long[2048];
 		data[0]=-4294977032L;
@@ -2527,8 +2568,8 @@ _loop110_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_2_ = new BitSet(mk_tokenSet_2_());
-	private static long[] mk_tokenSet_3_()
+	public static readonly BitSet tokenSet_4_ = new BitSet(mk_tokenSet_4_());
+	private static long[] mk_tokenSet_5_()
 	{
 		long[] data = new long[2048];
 		data[0]=-549755823112L;
@@ -2538,8 +2579,8 @@ _loop110_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_3_ = new BitSet(mk_tokenSet_3_());
-	private static long[] mk_tokenSet_4_()
+	public static readonly BitSet tokenSet_5_ = new BitSet(mk_tokenSet_5_());
+	private static long[] mk_tokenSet_6_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140741783332360L;
@@ -2549,7 +2590,7 @@ _loop110_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_4_ = new BitSet(mk_tokenSet_4_());
+	public static readonly BitSet tokenSet_6_ = new BitSet(mk_tokenSet_6_());
 	
 }
 }
