@@ -27,7 +27,7 @@
 #endregion
 
 
-// $ANTLR 2.7.5 (20050517): "wsabooel.g" -> "WSABooExpressionLexer.cs"$
+// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/wsabooel.g" -> "WSABooExpressionLexer.cs"$
 
 namespace Boo.Lang.Parser
 {
@@ -103,8 +103,8 @@ namespace Boo.Lang.Parser
 		public const int WHEN = 69;
 		public const int WHILE = 70;
 		public const int YIELD = 71;
-		public const int EOS = 72;
-		public const int TRIPLE_QUOTED_STRING = 73;
+		public const int TRIPLE_QUOTED_STRING = 72;
+		public const int EOS = 73;
 		public const int DOUBLE_QUOTED_STRING = 74;
 		public const int SINGLE_QUOTED_STRING = 75;
 		public const int ID = 76;
@@ -162,9 +162,10 @@ namespace Boo.Lang.Parser
 		public const int RE_ESC = 128;
 		public const int DIGIT_GROUP = 129;
 		public const int REVERSE_DIGIT_GROUP = 130;
-		public const int ID_LETTER = 131;
-		public const int DIGIT = 132;
-		public const int HEXDIGIT = 133;
+		public const int ID_PREFIX = 131;
+		public const int ID_LETTER = 132;
+		public const int DIGIT = 133;
+		public const int HEXDIGIT = 134;
 		
 	}
 }
