@@ -27,7 +27,7 @@
 #endregion
 
 
-// $ANTLR 2.7.5 (20050517): "wsaboo.g" -> "WSABooLexer.cs"$
+// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/wsaboo.g" -> "WSABooLexer.cs"$
 
 namespace Boo.Lang.Parser
 {
@@ -133,8 +133,8 @@ using Boo.Lang.Parser.Util;
 		public const int WHEN = 69;
 		public const int WHILE = 70;
 		public const int YIELD = 71;
-		public const int EOS = 72;
-		public const int TRIPLE_QUOTED_STRING = 73;
+		public const int TRIPLE_QUOTED_STRING = 72;
+		public const int EOS = 73;
 		public const int DOUBLE_QUOTED_STRING = 74;
 		public const int SINGLE_QUOTED_STRING = 75;
 		public const int ID = 76;
@@ -192,9 +192,10 @@ using Boo.Lang.Parser.Util;
 		public const int RE_ESC = 128;
 		public const int DIGIT_GROUP = 129;
 		public const int REVERSE_DIGIT_GROUP = 130;
-		public const int ID_LETTER = 131;
-		public const int DIGIT = 132;
-		public const int HEXDIGIT = 133;
+		public const int ID_PREFIX = 131;
+		public const int ID_LETTER = 132;
+		public const int DIGIT = 133;
+		public const int HEXDIGIT = 134;
 		
 		
 	protected int _skipWhitespaceRegion = 0;
@@ -358,25 +359,6 @@ tryAgain:
 					{
 						switch ( cached_LA1 )
 						{
-						case 'A':  case 'B':  case 'C':  case 'D':
-						case 'E':  case 'F':  case 'G':  case 'H':
-						case 'I':  case 'J':  case 'K':  case 'L':
-						case 'M':  case 'N':  case 'O':  case 'P':
-						case 'Q':  case 'R':  case 'S':  case 'T':
-						case 'U':  case 'V':  case 'W':  case 'X':
-						case 'Y':  case 'Z':  case '_':  case 'a':
-						case 'b':  case 'c':  case 'd':  case 'e':
-						case 'f':  case 'g':  case 'h':  case 'i':
-						case 'j':  case 'k':  case 'l':  case 'm':
-						case 'n':  case 'o':  case 'p':  case 'q':
-						case 'r':  case 's':  case 't':  case 'u':
-						case 'v':  case 'w':  case 'x':  case 'y':
-						case 'z':
-						{
-							mID(true);
-							theRetToken = returnToken_;
-							break;
-						}
 						case '\\':
 						{
 							mLINE_CONTINUATION(true);
@@ -523,12 +505,6 @@ tryAgain:
 							theRetToken = returnToken_;
 							break;
 						}
-						case '@':
-						{
-							mX_RE_LITERAL(true);
-							theRetToken = returnToken_;
-							break;
-						}
 						default:
 							if ((cached_LA1=='<') && (cached_LA2=='<') && (LA(3)=='='))
 							{
@@ -563,6 +539,14 @@ tryAgain:
 								mCMP_OPERATOR(true);
 								theRetToken = returnToken_;
 							}
+							else if ((cached_LA1=='@') && (cached_LA2=='/')) {
+								mX_RE_LITERAL(true);
+								theRetToken = returnToken_;
+							}
+							else if ((tokenSet_0_.member(cached_LA1)) && (true)) {
+								mID(true);
+								theRetToken = returnToken_;
+							}
 							else if ((cached_LA1=='+') && (true)) {
 								mADD(true);
 								theRetToken = returnToken_;
@@ -614,44 +598,37 @@ tryAgain:
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = ID;
 		
+		{
+			if ((cached_LA1=='$'||cached_LA1=='?'||cached_LA1=='@'))
+			{
+				mID_PREFIX(false);
+			}
+			else if ((tokenSet_1_.member(cached_LA1))) {
+			}
+			else
+			{
+				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+			}
+			
+		}
 		mID_LETTER(false);
 		{    // ( ... )*
 			for (;;)
 			{
-				switch ( cached_LA1 )
-				{
-				case 'A':  case 'B':  case 'C':  case 'D':
-				case 'E':  case 'F':  case 'G':  case 'H':
-				case 'I':  case 'J':  case 'K':  case 'L':
-				case 'M':  case 'N':  case 'O':  case 'P':
-				case 'Q':  case 'R':  case 'S':  case 'T':
-				case 'U':  case 'V':  case 'W':  case 'X':
-				case 'Y':  case 'Z':  case '_':  case 'a':
-				case 'b':  case 'c':  case 'd':  case 'e':
-				case 'f':  case 'g':  case 'h':  case 'i':
-				case 'j':  case 'k':  case 'l':  case 'm':
-				case 'n':  case 'o':  case 'p':  case 'q':
-				case 'r':  case 's':  case 't':  case 'u':
-				case 'v':  case 'w':  case 'x':  case 'y':
-				case 'z':
+				if ((tokenSet_1_.member(cached_LA1)))
 				{
 					mID_LETTER(false);
-					break;
 				}
-				case '0':  case '1':  case '2':  case '3':
-				case '4':  case '5':  case '6':  case '7':
-				case '8':  case '9':
-				{
+				else if (((cached_LA1 >= '0' && cached_LA1 <= '9'))) {
 					mDIGIT(false);
-					break;
 				}
-				default:
+				else
 				{
-					goto _loop503_breakloop;
+					goto _loop504_breakloop;
 				}
-				 }
+				
 			}
-_loop503_breakloop:			;
+_loop504_breakloop:			;
 		}    // ( ... )*
 		_ttype = testLiteralsTable(_ttype);
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -662,6 +639,41 @@ _loop503_breakloop:			;
 		returnToken_ = _token;
 	}
 	
+	protected void mID_PREFIX(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
+{
+		int _ttype; IToken _token=null; int _begin=text.Length;
+		_ttype = ID_PREFIX;
+		
+		switch ( cached_LA1 )
+		{
+		case '$':
+		{
+			match('$');
+			break;
+		}
+		case '@':
+		{
+			match('@');
+			break;
+		}
+		case '?':
+		{
+			match('?');
+			break;
+		}
+		default:
+		{
+			throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
+		}
+		 }
+		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
+		{
+			_token = makeToken(_ttype);
+			_token.setText(text.ToString(_begin, text.Length-_begin));
+		}
+		returnToken_ = _token;
+	}
+	
 	protected void mID_LETTER(bool _createToken) //throws RecognitionException, CharStreamException, TokenStreamException
 {
 		int _ttype; IToken _token=null; int _begin=text.Length;
@@ -698,10 +710,15 @@ _loop503_breakloop:			;
 				break;
 			}
 			default:
+				if ((((cached_LA1 >= '\u0080' && cached_LA1 <= '\ufffe')))&&(System.Char.IsLetter(LA(1))))
+				{
+					matchRange('\u0080','\uFFFE');
+				}
+			else
 			{
 				throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());
 			}
-			 }
+			break; }
 		}
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -753,7 +770,7 @@ _loop503_breakloop:			;
 		_ttype = NEWLINE;
 		
 		{ // ( ... )+
-			int _cnt633=0;
+			int _cnt634=0;
 			for (;;)
 			{
 				if ((cached_LA1=='\n'||cached_LA1=='\r') && (true) && (true))
@@ -795,12 +812,12 @@ _loop503_breakloop:			;
 				}
 				else
 				{
-					if (_cnt633 >= 1) { goto _loop633_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt634 >= 1) { goto _loop634_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt633++;
+				_cnt634++;
 			}
-_loop633_breakloop:			;
+_loop634_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -833,21 +850,21 @@ _loop633_breakloop:			;
 			{
 				match("0x");
 				{ // ( ... )+
-					int _cnt508=0;
+					int _cnt509=0;
 					for (;;)
 					{
-						if ((tokenSet_0_.member(cached_LA1)))
+						if ((tokenSet_2_.member(cached_LA1)))
 						{
 							mHEXDIGIT(false);
 						}
 						else
 						{
-							if (_cnt508 >= 1) { goto _loop508_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt509 >= 1) { goto _loop509_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt508++;
+						_cnt509++;
 					}
-_loop508_breakloop:					;
+_loop509_breakloop:					;
 				}    // ( ... )+
 			}
 			{
@@ -1237,11 +1254,11 @@ _loop508_breakloop:					;
 				}
 				default:
 				{
-					goto _loop665_breakloop;
+					goto _loop666_breakloop;
 				}
 				 }
 			}
-_loop665_breakloop:			;
+_loop666_breakloop:			;
 		}    // ( ... )*
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1257,7 +1274,7 @@ _loop665_breakloop:			;
 		_ttype = REVERSE_DIGIT_GROUP;
 		
 		{ // ( ... )+
-			int _cnt669=0;
+			int _cnt670=0;
 			for (;;)
 			{
 				if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && ((cached_LA2 >= '0' && cached_LA2 <= '9')) && ((LA(3) >= '0' && LA(3) <= '9')))
@@ -1283,12 +1300,12 @@ _loop665_breakloop:			;
 				}
 				else
 				{
-					if (_cnt669 >= 1) { goto _loop669_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt670 >= 1) { goto _loop670_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt669++;
+				_cnt670++;
 			}
-_loop669_breakloop:			;
+_loop670_breakloop:			;
 		}    // ( ... )+
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
 		{
@@ -1613,11 +1630,11 @@ _loop669_breakloop:			;
 			EnterSkipWhitespaceRegion();
 		}
 		{
-			bool synPredMatched552 = false;
+			bool synPredMatched553 = false;
 			if (((cached_LA1=='a')))
 			{
-				int _m552 = mark();
-				synPredMatched552 = true;
+				int _m553 = mark();
+				synPredMatched553 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1626,12 +1643,12 @@ _loop669_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched552 = false;
+					synPredMatched553 = false;
 				}
-				rewind(_m552);
+				rewind(_m553);
 				inputState.guessing--;
 			}
-			if ( synPredMatched552 )
+			if ( synPredMatched553 )
 			{
 				match("assembly:");
 				if (0==inputState.guessing)
@@ -1851,11 +1868,11 @@ _loop669_breakloop:			;
 		int _ttype; IToken _token=null; int _begin=text.Length;
 		_ttype = DIVISION;
 		
-		bool synPredMatched570 = false;
+		bool synPredMatched571 = false;
 		if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 		{
-			int _m570 = mark();
-			synPredMatched570 = true;
+			int _m571 = mark();
+			synPredMatched571 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -1864,12 +1881,12 @@ _loop669_breakloop:			;
 			}
 			catch (RecognitionException)
 			{
-				synPredMatched570 = false;
+				synPredMatched571 = false;
 			}
-			rewind(_m570);
+			rewind(_m571);
 			inputState.guessing--;
 		}
-		if ( synPredMatched570 )
+		if ( synPredMatched571 )
 		{
 			mML_COMMENT(false);
 			if (0==inputState.guessing)
@@ -1878,11 +1895,11 @@ _loop669_breakloop:			;
 			}
 		}
 		else {
-			bool synPredMatched572 = false;
-			if (((cached_LA1=='/') && (tokenSet_1_.member(cached_LA2)) && (tokenSet_2_.member(LA(3)))))
+			bool synPredMatched573 = false;
+			if (((cached_LA1=='/') && (tokenSet_3_.member(cached_LA2)) && (tokenSet_4_.member(LA(3)))))
 			{
-				int _m572 = mark();
-				synPredMatched572 = true;
+				int _m573 = mark();
+				synPredMatched573 = true;
 				inputState.guessing++;
 				try {
 					{
@@ -1891,12 +1908,12 @@ _loop669_breakloop:			;
 				}
 				catch (RecognitionException)
 				{
-					synPredMatched572 = false;
+					synPredMatched573 = false;
 				}
-				rewind(_m572);
+				rewind(_m573);
 				inputState.guessing--;
 			}
-			if ( synPredMatched572 )
+			if ( synPredMatched573 )
 			{
 				mRE_LITERAL(false);
 				if (0==inputState.guessing)
@@ -1916,19 +1933,19 @@ _loop669_breakloop:			;
 							{    // ( ... )*
 								for (;;)
 								{
-									if ((tokenSet_3_.member(cached_LA1)))
+									if ((tokenSet_5_.member(cached_LA1)))
 									{
 										{
-											match(tokenSet_3_);
+											match(tokenSet_5_);
 										}
 									}
 									else
 									{
-										goto _loop577_breakloop;
+										goto _loop578_breakloop;
 									}
 									
 								}
-_loop577_breakloop:								;
+_loop578_breakloop:								;
 							}    // ( ... )*
 							if (0==inputState.guessing)
 							{
@@ -1981,11 +1998,11 @@ _loop577_breakloop:								;
 					match('*');
 				}
 				else {
-					bool synPredMatched618 = false;
+					bool synPredMatched619 = false;
 					if (((cached_LA1=='/') && (cached_LA2=='*') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m618 = mark();
-						synPredMatched618 = true;
+						int _m619 = mark();
+						synPredMatched619 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -1994,18 +2011,18 @@ _loop577_breakloop:								;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched618 = false;
+							synPredMatched619 = false;
 						}
-						rewind(_m618);
+						rewind(_m619);
 						inputState.guessing--;
 					}
-					if ( synPredMatched618 )
+					if ( synPredMatched619 )
 					{
 						mML_COMMENT(false);
 					}
-					else if ((tokenSet_4_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
+					else if ((tokenSet_6_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
 						{
-							match(tokenSet_4_);
+							match(tokenSet_6_);
 						}
 					}
 					else if ((cached_LA1=='\n'||cached_LA1=='\r')) {
@@ -2013,11 +2030,11 @@ _loop577_breakloop:								;
 					}
 					else
 					{
-						goto _loop620_breakloop;
+						goto _loop621_breakloop;
 					}
 					}
 				}
-_loop620_breakloop:				;
+_loop621_breakloop:				;
 			}    // ( ... )*
 			match("*/");
 			if (0==inputState.guessing)
@@ -2039,21 +2056,21 @@ _loop620_breakloop:				;
 		
 		match('/');
 		{ // ( ... )+
-			int _cnt651=0;
+			int _cnt652=0;
 			for (;;)
 			{
-				if ((tokenSet_1_.member(cached_LA1)))
+				if ((tokenSet_3_.member(cached_LA1)))
 				{
 					mRE_CHAR(false);
 				}
 				else
 				{
-					if (_cnt651 >= 1) { goto _loop651_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt652 >= 1) { goto _loop652_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt651++;
+				_cnt652++;
 			}
-_loop651_breakloop:			;
+_loop652_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (_createToken && (null == _token) && (_ttype != Token.SKIP))
@@ -2272,12 +2289,12 @@ _loop651_breakloop:			;
 			for (;;)
 			{
 				// nongreedy exit test
-				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop598_breakloop;
-				bool synPredMatched594 = false;
+				if ((cached_LA1=='"') && (cached_LA2=='"') && (LA(3)=='"')) goto _loop599_breakloop;
+				bool synPredMatched595 = false;
 				if (((cached_LA1=='$') && (cached_LA2=='{') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 				{
-					int _m594 = mark();
-					synPredMatched594 = true;
+					int _m595 = mark();
+					synPredMatched595 = true;
 					inputState.guessing++;
 					try {
 						{
@@ -2286,12 +2303,12 @@ _loop651_breakloop:			;
 					}
 					catch (RecognitionException)
 					{
-						synPredMatched594 = false;
+						synPredMatched595 = false;
 					}
-					rewind(_m594);
+					rewind(_m595);
 					inputState.guessing--;
 				}
-				if ( synPredMatched594 )
+				if ( synPredMatched595 )
 				{
 					if (0==inputState.guessing)
 					{
@@ -2303,11 +2320,11 @@ _loop651_breakloop:			;
 					mESCAPED_EXPRESSION(false);
 				}
 				else {
-					bool synPredMatched596 = false;
+					bool synPredMatched597 = false;
 					if (((cached_LA1=='\\') && (cached_LA2=='$') && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))))
 					{
-						int _m596 = mark();
-						synPredMatched596 = true;
+						int _m597 = mark();
+						synPredMatched597 = true;
 						inputState.guessing++;
 						try {
 							{
@@ -2316,21 +2333,21 @@ _loop651_breakloop:			;
 						}
 						catch (RecognitionException)
 						{
-							synPredMatched596 = false;
+							synPredMatched597 = false;
 						}
-						rewind(_m596);
+						rewind(_m597);
 						inputState.guessing--;
 					}
-					if ( synPredMatched596 )
+					if ( synPredMatched597 )
 					{
 						_saveIndex = text.Length;
 						match('\\');
 						text.Length = _saveIndex;
 						match('$');
 					}
-					else if ((tokenSet_3_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
+					else if ((tokenSet_5_.member(cached_LA1)) && ((cached_LA2 >= '\u0003' && cached_LA2 <= '\ufffe')) && ((LA(3) >= '\u0003' && LA(3) <= '\ufffe'))) {
 						{
-							match(tokenSet_3_);
+							match(tokenSet_5_);
 						}
 					}
 					else if ((cached_LA1=='\n'||cached_LA1=='\r')) {
@@ -2338,11 +2355,11 @@ _loop651_breakloop:			;
 					}
 					else
 					{
-						goto _loop598_breakloop;
+						goto _loop599_breakloop;
 					}
 					}
 				}
-_loop598_breakloop:				;
+_loop599_breakloop:				;
 			}    // ( ... )*
 			_saveIndex = text.Length;
 			match("\"\"\"");
@@ -2405,16 +2422,16 @@ _loop598_breakloop:				;
 					_ttype = TRIPLE_QUOTED_STRING;
 				}
 			}
-			else if ((tokenSet_3_.member(cached_LA1)) && (true) && (true)) {
+			else if ((tokenSet_5_.member(cached_LA1)) && (true) && (true)) {
 				{
 					{    // ( ... )*
 						for (;;)
 						{
-							bool synPredMatched604 = false;
-							if (((cached_LA1=='$') && (cached_LA2=='{') && (tokenSet_3_.member(LA(3)))))
+							bool synPredMatched605 = false;
+							if (((cached_LA1=='$') && (cached_LA2=='{') && (tokenSet_5_.member(LA(3)))))
 							{
-								int _m604 = mark();
-								synPredMatched604 = true;
+								int _m605 = mark();
+								synPredMatched605 = true;
 								inputState.guessing++;
 								try {
 									{
@@ -2423,12 +2440,12 @@ _loop598_breakloop:				;
 								}
 								catch (RecognitionException)
 								{
-									synPredMatched604 = false;
+									synPredMatched605 = false;
 								}
-								rewind(_m604);
+								rewind(_m605);
 								inputState.guessing--;
 							}
-							if ( synPredMatched604 )
+							if ( synPredMatched605 )
 							{
 								if (0==inputState.guessing)
 								{
@@ -2439,9 +2456,9 @@ _loop598_breakloop:				;
 								}
 								mESCAPED_EXPRESSION(false);
 							}
-							else if ((tokenSet_5_.member(cached_LA1)) && (tokenSet_3_.member(cached_LA2)) && (true)) {
+							else if ((tokenSet_7_.member(cached_LA1)) && (tokenSet_5_.member(cached_LA2)) && (true)) {
 								{
-									match(tokenSet_5_);
+									match(tokenSet_7_);
 								}
 							}
 							else if ((cached_LA1=='\\')) {
@@ -2449,11 +2466,11 @@ _loop598_breakloop:				;
 							}
 							else
 							{
-								goto _loop606_breakloop;
+								goto _loop607_breakloop;
 							}
 							
 						}
-_loop606_breakloop:						;
+_loop607_breakloop:						;
 					}    // ( ... )*
 					_saveIndex = text.Length;
 					match('"');
@@ -2545,18 +2562,18 @@ _loop606_breakloop:						;
 				{
 					mSQS_ESC(false);
 				}
-				else if ((tokenSet_6_.member(cached_LA1))) {
+				else if ((tokenSet_8_.member(cached_LA1))) {
 					{
-						match(tokenSet_6_);
+						match(tokenSet_8_);
 					}
 				}
 				else
 				{
-					goto _loop610_breakloop;
+					goto _loop611_breakloop;
 				}
 				
 			}
-_loop610_breakloop:			;
+_loop611_breakloop:			;
 		}    // ( ... )*
 		_saveIndex = text.Length;
 		match('\'');
@@ -2616,19 +2633,19 @@ _loop610_breakloop:			;
 		{    // ( ... )*
 			for (;;)
 			{
-				if ((tokenSet_3_.member(cached_LA1)))
+				if ((tokenSet_5_.member(cached_LA1)))
 				{
 					{
-						match(tokenSet_3_);
+						match(tokenSet_5_);
 					}
 				}
 				else
 				{
-					goto _loop614_breakloop;
+					goto _loop615_breakloop;
 				}
 				
 			}
-_loop614_breakloop:			;
+_loop615_breakloop:			;
 		}    // ( ... )*
 		if (0==inputState.guessing)
 		{
@@ -2648,7 +2665,7 @@ _loop614_breakloop:			;
 		_ttype = WS;
 		
 		{ // ( ... )+
-			int _cnt623=0;
+			int _cnt624=0;
 			for (;;)
 			{
 				switch ( cached_LA1 )
@@ -2674,12 +2691,12 @@ _loop614_breakloop:			;
 				}
 				default:
 				{
-					if (_cnt623 >= 1) { goto _loop623_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt624 >= 1) { goto _loop624_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				break; }
-				_cnt623++;
+				_cnt624++;
 			}
-_loop623_breakloop:			;
+_loop624_breakloop:			;
 		}    // ( ... )+
 		if (0==inputState.guessing)
 		{
@@ -2720,21 +2737,21 @@ _loop623_breakloop:			;
 		text.Length = _saveIndex;
 		match('/');
 		{ // ( ... )+
-			int _cnt627=0;
+			int _cnt628=0;
 			for (;;)
 			{
-				if ((tokenSet_7_.member(cached_LA1)))
+				if ((tokenSet_9_.member(cached_LA1)))
 				{
 					mX_RE_CHAR(false);
 				}
 				else
 				{
-					if (_cnt627 >= 1) { goto _loop627_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+					if (_cnt628 >= 1) { goto _loop628_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 				}
 				
-				_cnt627++;
+				_cnt628++;
 			}
-_loop627_breakloop:			;
+_loop628_breakloop:			;
 		}    // ( ... )+
 		match('/');
 		if (0==inputState.guessing)
@@ -2767,7 +2784,7 @@ _loop627_breakloop:			;
 			break;
 		}
 		default:
-			if ((tokenSet_1_.member(cached_LA1)))
+			if ((tokenSet_3_.member(cached_LA1)))
 			{
 				mRE_CHAR(false);
 			}
@@ -2947,9 +2964,9 @@ _loop627_breakloop:			;
 		{
 			mRE_ESC(false);
 		}
-		else if ((tokenSet_8_.member(cached_LA1))) {
+		else if ((tokenSet_10_.member(cached_LA1))) {
 			{
-				match(tokenSet_8_);
+				match(tokenSet_10_);
 			}
 		}
 		else
@@ -3097,21 +3114,21 @@ _loop627_breakloop:			;
 			case '8':  case '9':
 			{
 				{ // ( ... )+
-					int _cnt659=0;
+					int _cnt660=0;
 					for (;;)
 					{
-						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_3_.member(cached_LA2)) && (true))
+						if (((cached_LA1 >= '0' && cached_LA1 <= '9')) && (tokenSet_5_.member(cached_LA2)) && (true))
 						{
 							mDIGIT(false);
 						}
 						else
 						{
-							if (_cnt659 >= 1) { goto _loop659_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
+							if (_cnt660 >= 1) { goto _loop660_breakloop; } else { throw new NoViableAltForCharException(cached_LA1, getFilename(), getLine(), getColumn());; }
 						}
 						
-						_cnt659++;
+						_cnt660++;
 					}
-_loop659_breakloop:					;
+_loop660_breakloop:					;
 				}    // ( ... )+
 				break;
 			}
@@ -3226,6 +3243,28 @@ _loop659_breakloop:					;
 	
 	
 	private static long[] mk_tokenSet_0_()
+	{
+		long[] data = new long[3072];
+		data[0]=-9223371968135299072L;
+		data[1]=576460745995190271L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
+	private static long[] mk_tokenSet_1_()
+	{
+		long[] data = new long[3072];
+		data[0]=0L;
+		data[1]=576460745995190270L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=3071; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
+	private static long[] mk_tokenSet_2_()
 	{
 		long[] data = new long[1025];
 		data[0]=287948901175001088L;
@@ -3233,31 +3272,11 @@ _loop659_breakloop:					;
 		for (int i = 2; i<=1024; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_0_ = new BitSet(mk_tokenSet_0_());
-	private static long[] mk_tokenSet_1_()
-	{
-		long[] data = new long[2048];
-		data[0]=-140741783332360L;
-		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
-		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
-		return data;
-	}
-	public static readonly BitSet tokenSet_1_ = new BitSet(mk_tokenSet_1_());
-	private static long[] mk_tokenSet_2_()
-	{
-		long[] data = new long[2048];
-		data[0]=-4294977032L;
-		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
-		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
-		return data;
-	}
 	public static readonly BitSet tokenSet_2_ = new BitSet(mk_tokenSet_2_());
 	private static long[] mk_tokenSet_3_()
 	{
 		long[] data = new long[2048];
-		data[0]=-9224L;
+		data[0]=-140741783332360L;
 		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
@@ -3267,7 +3286,7 @@ _loop659_breakloop:					;
 	private static long[] mk_tokenSet_4_()
 	{
 		long[] data = new long[2048];
-		data[0]=-4398046520328L;
+		data[0]=-4294977032L;
 		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
@@ -3275,6 +3294,26 @@ _loop659_breakloop:					;
 	}
 	public static readonly BitSet tokenSet_4_ = new BitSet(mk_tokenSet_4_());
 	private static long[] mk_tokenSet_5_()
+	{
+		long[] data = new long[2048];
+		data[0]=-9224L;
+		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_5_ = new BitSet(mk_tokenSet_5_());
+	private static long[] mk_tokenSet_6_()
+	{
+		long[] data = new long[2048];
+		data[0]=-4398046520328L;
+		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
+		return data;
+	}
+	public static readonly BitSet tokenSet_6_ = new BitSet(mk_tokenSet_6_());
+	private static long[] mk_tokenSet_7_()
 	{
 		long[] data = new long[2048];
 		data[0]=-17179878408L;
@@ -3284,8 +3323,8 @@ _loop659_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_5_ = new BitSet(mk_tokenSet_5_());
-	private static long[] mk_tokenSet_6_()
+	public static readonly BitSet tokenSet_7_ = new BitSet(mk_tokenSet_7_());
+	private static long[] mk_tokenSet_8_()
 	{
 		long[] data = new long[2048];
 		data[0]=-549755823112L;
@@ -3295,8 +3334,8 @@ _loop659_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_6_ = new BitSet(mk_tokenSet_6_());
-	private static long[] mk_tokenSet_7_()
+	public static readonly BitSet tokenSet_8_ = new BitSet(mk_tokenSet_8_());
+	private static long[] mk_tokenSet_9_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140737488364552L;
@@ -3305,8 +3344,8 @@ _loop659_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_7_ = new BitSet(mk_tokenSet_7_());
-	private static long[] mk_tokenSet_8_()
+	public static readonly BitSet tokenSet_9_ = new BitSet(mk_tokenSet_9_());
+	private static long[] mk_tokenSet_10_()
 	{
 		long[] data = new long[2048];
 		data[0]=-140741783332360L;
@@ -3316,7 +3355,7 @@ _loop659_breakloop:					;
 		for (int i = 1024; i<=2047; i++) { data[i]=0L; }
 		return data;
 	}
-	public static readonly BitSet tokenSet_8_ = new BitSet(mk_tokenSet_8_());
+	public static readonly BitSet tokenSet_10_ = new BitSet(mk_tokenSet_10_());
 	
 }
 }
